/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Intrinsic Function Source Fragment                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_IR_INTRINSIC_LOONGARCH_ENUMS_H
#define LLVM_IR_INTRINSIC_LOONGARCH_ENUMS_H
namespace llvm::Intrinsic {
enum LOONGARCHIntrinsics : unsigned {
// Enum values for intrinsics.
    loongarch_asrtgt_d = 5932,                        // llvm.loongarch.asrtgt.d
    loongarch_asrtle_d,                        // llvm.loongarch.asrtle.d
    loongarch_break,                           // llvm.loongarch.break
    loongarch_cacop_d,                         // llvm.loongarch.cacop.d
    loongarch_cacop_w,                         // llvm.loongarch.cacop.w
    loongarch_cpucfg,                          // llvm.loongarch.cpucfg
    loongarch_crc_w_b_w,                       // llvm.loongarch.crc.w.b.w
    loongarch_crc_w_d_w,                       // llvm.loongarch.crc.w.d.w
    loongarch_crc_w_h_w,                       // llvm.loongarch.crc.w.h.w
    loongarch_crc_w_w_w,                       // llvm.loongarch.crc.w.w.w
    loongarch_crcc_w_b_w,                      // llvm.loongarch.crcc.w.b.w
    loongarch_crcc_w_d_w,                      // llvm.loongarch.crcc.w.d.w
    loongarch_crcc_w_h_w,                      // llvm.loongarch.crcc.w.h.w
    loongarch_crcc_w_w_w,                      // llvm.loongarch.crcc.w.w.w
    loongarch_csrrd_d,                         // llvm.loongarch.csrrd.d
    loongarch_csrrd_w,                         // llvm.loongarch.csrrd.w
    loongarch_csrwr_d,                         // llvm.loongarch.csrwr.d
    loongarch_csrwr_w,                         // llvm.loongarch.csrwr.w
    loongarch_csrxchg_d,                       // llvm.loongarch.csrxchg.d
    loongarch_csrxchg_w,                       // llvm.loongarch.csrxchg.w
    loongarch_dbar,                            // llvm.loongarch.dbar
    loongarch_frecipe_d,                       // llvm.loongarch.frecipe.d
    loongarch_frecipe_s,                       // llvm.loongarch.frecipe.s
    loongarch_frsqrte_d,                       // llvm.loongarch.frsqrte.d
    loongarch_frsqrte_s,                       // llvm.loongarch.frsqrte.s
    loongarch_ibar,                            // llvm.loongarch.ibar
    loongarch_iocsrrd_b,                       // llvm.loongarch.iocsrrd.b
    loongarch_iocsrrd_d,                       // llvm.loongarch.iocsrrd.d
    loongarch_iocsrrd_h,                       // llvm.loongarch.iocsrrd.h
    loongarch_iocsrrd_w,                       // llvm.loongarch.iocsrrd.w
    loongarch_iocsrwr_b,                       // llvm.loongarch.iocsrwr.b
    loongarch_iocsrwr_d,                       // llvm.loongarch.iocsrwr.d
    loongarch_iocsrwr_h,                       // llvm.loongarch.iocsrwr.h
    loongarch_iocsrwr_w,                       // llvm.loongarch.iocsrwr.w
    loongarch_lasx_vext2xv_d_b,                // llvm.loongarch.lasx.vext2xv.d.b
    loongarch_lasx_vext2xv_d_h,                // llvm.loongarch.lasx.vext2xv.d.h
    loongarch_lasx_vext2xv_d_w,                // llvm.loongarch.lasx.vext2xv.d.w
    loongarch_lasx_vext2xv_du_bu,              // llvm.loongarch.lasx.vext2xv.du.bu
    loongarch_lasx_vext2xv_du_hu,              // llvm.loongarch.lasx.vext2xv.du.hu
    loongarch_lasx_vext2xv_du_wu,              // llvm.loongarch.lasx.vext2xv.du.wu
    loongarch_lasx_vext2xv_h_b,                // llvm.loongarch.lasx.vext2xv.h.b
    loongarch_lasx_vext2xv_hu_bu,              // llvm.loongarch.lasx.vext2xv.hu.bu
    loongarch_lasx_vext2xv_w_b,                // llvm.loongarch.lasx.vext2xv.w.b
    loongarch_lasx_vext2xv_w_h,                // llvm.loongarch.lasx.vext2xv.w.h
    loongarch_lasx_vext2xv_wu_bu,              // llvm.loongarch.lasx.vext2xv.wu.bu
    loongarch_lasx_vext2xv_wu_hu,              // llvm.loongarch.lasx.vext2xv.wu.hu
    loongarch_lasx_xbnz_b,                     // llvm.loongarch.lasx.xbnz.b
    loongarch_lasx_xbnz_d,                     // llvm.loongarch.lasx.xbnz.d
    loongarch_lasx_xbnz_h,                     // llvm.loongarch.lasx.xbnz.h
    loongarch_lasx_xbnz_v,                     // llvm.loongarch.lasx.xbnz.v
    loongarch_lasx_xbnz_w,                     // llvm.loongarch.lasx.xbnz.w
    loongarch_lasx_xbz_b,                      // llvm.loongarch.lasx.xbz.b
    loongarch_lasx_xbz_d,                      // llvm.loongarch.lasx.xbz.d
    loongarch_lasx_xbz_h,                      // llvm.loongarch.lasx.xbz.h
    loongarch_lasx_xbz_v,                      // llvm.loongarch.lasx.xbz.v
    loongarch_lasx_xbz_w,                      // llvm.loongarch.lasx.xbz.w
    loongarch_lasx_xvabsd_b,                   // llvm.loongarch.lasx.xvabsd.b
    loongarch_lasx_xvabsd_bu,                  // llvm.loongarch.lasx.xvabsd.bu
    loongarch_lasx_xvabsd_d,                   // llvm.loongarch.lasx.xvabsd.d
    loongarch_lasx_xvabsd_du,                  // llvm.loongarch.lasx.xvabsd.du
    loongarch_lasx_xvabsd_h,                   // llvm.loongarch.lasx.xvabsd.h
    loongarch_lasx_xvabsd_hu,                  // llvm.loongarch.lasx.xvabsd.hu
    loongarch_lasx_xvabsd_w,                   // llvm.loongarch.lasx.xvabsd.w
    loongarch_lasx_xvabsd_wu,                  // llvm.loongarch.lasx.xvabsd.wu
    loongarch_lasx_xvadd_b,                    // llvm.loongarch.lasx.xvadd.b
    loongarch_lasx_xvadd_d,                    // llvm.loongarch.lasx.xvadd.d
    loongarch_lasx_xvadd_h,                    // llvm.loongarch.lasx.xvadd.h
    loongarch_lasx_xvadd_q,                    // llvm.loongarch.lasx.xvadd.q
    loongarch_lasx_xvadd_w,                    // llvm.loongarch.lasx.xvadd.w
    loongarch_lasx_xvadda_b,                   // llvm.loongarch.lasx.xvadda.b
    loongarch_lasx_xvadda_d,                   // llvm.loongarch.lasx.xvadda.d
    loongarch_lasx_xvadda_h,                   // llvm.loongarch.lasx.xvadda.h
    loongarch_lasx_xvadda_w,                   // llvm.loongarch.lasx.xvadda.w
    loongarch_lasx_xvaddi_bu,                  // llvm.loongarch.lasx.xvaddi.bu
    loongarch_lasx_xvaddi_du,                  // llvm.loongarch.lasx.xvaddi.du
    loongarch_lasx_xvaddi_hu,                  // llvm.loongarch.lasx.xvaddi.hu
    loongarch_lasx_xvaddi_wu,                  // llvm.loongarch.lasx.xvaddi.wu
    loongarch_lasx_xvaddwev_d_w,               // llvm.loongarch.lasx.xvaddwev.d.w
    loongarch_lasx_xvaddwev_d_wu,              // llvm.loongarch.lasx.xvaddwev.d.wu
    loongarch_lasx_xvaddwev_d_wu_w,            // llvm.loongarch.lasx.xvaddwev.d.wu.w
    loongarch_lasx_xvaddwev_h_b,               // llvm.loongarch.lasx.xvaddwev.h.b
    loongarch_lasx_xvaddwev_h_bu,              // llvm.loongarch.lasx.xvaddwev.h.bu
    loongarch_lasx_xvaddwev_h_bu_b,            // llvm.loongarch.lasx.xvaddwev.h.bu.b
    loongarch_lasx_xvaddwev_q_d,               // llvm.loongarch.lasx.xvaddwev.q.d
    loongarch_lasx_xvaddwev_q_du,              // llvm.loongarch.lasx.xvaddwev.q.du
    loongarch_lasx_xvaddwev_q_du_d,            // llvm.loongarch.lasx.xvaddwev.q.du.d
    loongarch_lasx_xvaddwev_w_h,               // llvm.loongarch.lasx.xvaddwev.w.h
    loongarch_lasx_xvaddwev_w_hu,              // llvm.loongarch.lasx.xvaddwev.w.hu
    loongarch_lasx_xvaddwev_w_hu_h,            // llvm.loongarch.lasx.xvaddwev.w.hu.h
    loongarch_lasx_xvaddwod_d_w,               // llvm.loongarch.lasx.xvaddwod.d.w
    loongarch_lasx_xvaddwod_d_wu,              // llvm.loongarch.lasx.xvaddwod.d.wu
    loongarch_lasx_xvaddwod_d_wu_w,            // llvm.loongarch.lasx.xvaddwod.d.wu.w
    loongarch_lasx_xvaddwod_h_b,               // llvm.loongarch.lasx.xvaddwod.h.b
    loongarch_lasx_xvaddwod_h_bu,              // llvm.loongarch.lasx.xvaddwod.h.bu
    loongarch_lasx_xvaddwod_h_bu_b,            // llvm.loongarch.lasx.xvaddwod.h.bu.b
    loongarch_lasx_xvaddwod_q_d,               // llvm.loongarch.lasx.xvaddwod.q.d
    loongarch_lasx_xvaddwod_q_du,              // llvm.loongarch.lasx.xvaddwod.q.du
    loongarch_lasx_xvaddwod_q_du_d,            // llvm.loongarch.lasx.xvaddwod.q.du.d
    loongarch_lasx_xvaddwod_w_h,               // llvm.loongarch.lasx.xvaddwod.w.h
    loongarch_lasx_xvaddwod_w_hu,              // llvm.loongarch.lasx.xvaddwod.w.hu
    loongarch_lasx_xvaddwod_w_hu_h,            // llvm.loongarch.lasx.xvaddwod.w.hu.h
    loongarch_lasx_xvand_v,                    // llvm.loongarch.lasx.xvand.v
    loongarch_lasx_xvandi_b,                   // llvm.loongarch.lasx.xvandi.b
    loongarch_lasx_xvandn_v,                   // llvm.loongarch.lasx.xvandn.v
    loongarch_lasx_xvavg_b,                    // llvm.loongarch.lasx.xvavg.b
    loongarch_lasx_xvavg_bu,                   // llvm.loongarch.lasx.xvavg.bu
    loongarch_lasx_xvavg_d,                    // llvm.loongarch.lasx.xvavg.d
    loongarch_lasx_xvavg_du,                   // llvm.loongarch.lasx.xvavg.du
    loongarch_lasx_xvavg_h,                    // llvm.loongarch.lasx.xvavg.h
    loongarch_lasx_xvavg_hu,                   // llvm.loongarch.lasx.xvavg.hu
    loongarch_lasx_xvavg_w,                    // llvm.loongarch.lasx.xvavg.w
    loongarch_lasx_xvavg_wu,                   // llvm.loongarch.lasx.xvavg.wu
    loongarch_lasx_xvavgr_b,                   // llvm.loongarch.lasx.xvavgr.b
    loongarch_lasx_xvavgr_bu,                  // llvm.loongarch.lasx.xvavgr.bu
    loongarch_lasx_xvavgr_d,                   // llvm.loongarch.lasx.xvavgr.d
    loongarch_lasx_xvavgr_du,                  // llvm.loongarch.lasx.xvavgr.du
    loongarch_lasx_xvavgr_h,                   // llvm.loongarch.lasx.xvavgr.h
    loongarch_lasx_xvavgr_hu,                  // llvm.loongarch.lasx.xvavgr.hu
    loongarch_lasx_xvavgr_w,                   // llvm.loongarch.lasx.xvavgr.w
    loongarch_lasx_xvavgr_wu,                  // llvm.loongarch.lasx.xvavgr.wu
    loongarch_lasx_xvbitclr_b,                 // llvm.loongarch.lasx.xvbitclr.b
    loongarch_lasx_xvbitclr_d,                 // llvm.loongarch.lasx.xvbitclr.d
    loongarch_lasx_xvbitclr_h,                 // llvm.loongarch.lasx.xvbitclr.h
    loongarch_lasx_xvbitclr_w,                 // llvm.loongarch.lasx.xvbitclr.w
    loongarch_lasx_xvbitclri_b,                // llvm.loongarch.lasx.xvbitclri.b
    loongarch_lasx_xvbitclri_d,                // llvm.loongarch.lasx.xvbitclri.d
    loongarch_lasx_xvbitclri_h,                // llvm.loongarch.lasx.xvbitclri.h
    loongarch_lasx_xvbitclri_w,                // llvm.loongarch.lasx.xvbitclri.w
    loongarch_lasx_xvbitrev_b,                 // llvm.loongarch.lasx.xvbitrev.b
    loongarch_lasx_xvbitrev_d,                 // llvm.loongarch.lasx.xvbitrev.d
    loongarch_lasx_xvbitrev_h,                 // llvm.loongarch.lasx.xvbitrev.h
    loongarch_lasx_xvbitrev_w,                 // llvm.loongarch.lasx.xvbitrev.w
    loongarch_lasx_xvbitrevi_b,                // llvm.loongarch.lasx.xvbitrevi.b
    loongarch_lasx_xvbitrevi_d,                // llvm.loongarch.lasx.xvbitrevi.d
    loongarch_lasx_xvbitrevi_h,                // llvm.loongarch.lasx.xvbitrevi.h
    loongarch_lasx_xvbitrevi_w,                // llvm.loongarch.lasx.xvbitrevi.w
    loongarch_lasx_xvbitsel_v,                 // llvm.loongarch.lasx.xvbitsel.v
    loongarch_lasx_xvbitseli_b,                // llvm.loongarch.lasx.xvbitseli.b
    loongarch_lasx_xvbitset_b,                 // llvm.loongarch.lasx.xvbitset.b
    loongarch_lasx_xvbitset_d,                 // llvm.loongarch.lasx.xvbitset.d
    loongarch_lasx_xvbitset_h,                 // llvm.loongarch.lasx.xvbitset.h
    loongarch_lasx_xvbitset_w,                 // llvm.loongarch.lasx.xvbitset.w
    loongarch_lasx_xvbitseti_b,                // llvm.loongarch.lasx.xvbitseti.b
    loongarch_lasx_xvbitseti_d,                // llvm.loongarch.lasx.xvbitseti.d
    loongarch_lasx_xvbitseti_h,                // llvm.loongarch.lasx.xvbitseti.h
    loongarch_lasx_xvbitseti_w,                // llvm.loongarch.lasx.xvbitseti.w
    loongarch_lasx_xvbsll_v,                   // llvm.loongarch.lasx.xvbsll.v
    loongarch_lasx_xvbsrl_v,                   // llvm.loongarch.lasx.xvbsrl.v
    loongarch_lasx_xvclo_b,                    // llvm.loongarch.lasx.xvclo.b
    loongarch_lasx_xvclo_d,                    // llvm.loongarch.lasx.xvclo.d
    loongarch_lasx_xvclo_h,                    // llvm.loongarch.lasx.xvclo.h
    loongarch_lasx_xvclo_w,                    // llvm.loongarch.lasx.xvclo.w
    loongarch_lasx_xvclz_b,                    // llvm.loongarch.lasx.xvclz.b
    loongarch_lasx_xvclz_d,                    // llvm.loongarch.lasx.xvclz.d
    loongarch_lasx_xvclz_h,                    // llvm.loongarch.lasx.xvclz.h
    loongarch_lasx_xvclz_w,                    // llvm.loongarch.lasx.xvclz.w
    loongarch_lasx_xvdiv_b,                    // llvm.loongarch.lasx.xvdiv.b
    loongarch_lasx_xvdiv_bu,                   // llvm.loongarch.lasx.xvdiv.bu
    loongarch_lasx_xvdiv_d,                    // llvm.loongarch.lasx.xvdiv.d
    loongarch_lasx_xvdiv_du,                   // llvm.loongarch.lasx.xvdiv.du
    loongarch_lasx_xvdiv_h,                    // llvm.loongarch.lasx.xvdiv.h
    loongarch_lasx_xvdiv_hu,                   // llvm.loongarch.lasx.xvdiv.hu
    loongarch_lasx_xvdiv_w,                    // llvm.loongarch.lasx.xvdiv.w
    loongarch_lasx_xvdiv_wu,                   // llvm.loongarch.lasx.xvdiv.wu
    loongarch_lasx_xvexth_d_w,                 // llvm.loongarch.lasx.xvexth.d.w
    loongarch_lasx_xvexth_du_wu,               // llvm.loongarch.lasx.xvexth.du.wu
    loongarch_lasx_xvexth_h_b,                 // llvm.loongarch.lasx.xvexth.h.b
    loongarch_lasx_xvexth_hu_bu,               // llvm.loongarch.lasx.xvexth.hu.bu
    loongarch_lasx_xvexth_q_d,                 // llvm.loongarch.lasx.xvexth.q.d
    loongarch_lasx_xvexth_qu_du,               // llvm.loongarch.lasx.xvexth.qu.du
    loongarch_lasx_xvexth_w_h,                 // llvm.loongarch.lasx.xvexth.w.h
    loongarch_lasx_xvexth_wu_hu,               // llvm.loongarch.lasx.xvexth.wu.hu
    loongarch_lasx_xvextl_q_d,                 // llvm.loongarch.lasx.xvextl.q.d
    loongarch_lasx_xvextl_qu_du,               // llvm.loongarch.lasx.xvextl.qu.du
    loongarch_lasx_xvextrins_b,                // llvm.loongarch.lasx.xvextrins.b
    loongarch_lasx_xvextrins_d,                // llvm.loongarch.lasx.xvextrins.d
    loongarch_lasx_xvextrins_h,                // llvm.loongarch.lasx.xvextrins.h
    loongarch_lasx_xvextrins_w,                // llvm.loongarch.lasx.xvextrins.w
    loongarch_lasx_xvfadd_d,                   // llvm.loongarch.lasx.xvfadd.d
    loongarch_lasx_xvfadd_s,                   // llvm.loongarch.lasx.xvfadd.s
    loongarch_lasx_xvfclass_d,                 // llvm.loongarch.lasx.xvfclass.d
    loongarch_lasx_xvfclass_s,                 // llvm.loongarch.lasx.xvfclass.s
    loongarch_lasx_xvfcmp_caf_d,               // llvm.loongarch.lasx.xvfcmp.caf.d
    loongarch_lasx_xvfcmp_caf_s,               // llvm.loongarch.lasx.xvfcmp.caf.s
    loongarch_lasx_xvfcmp_ceq_d,               // llvm.loongarch.lasx.xvfcmp.ceq.d
    loongarch_lasx_xvfcmp_ceq_s,               // llvm.loongarch.lasx.xvfcmp.ceq.s
    loongarch_lasx_xvfcmp_cle_d,               // llvm.loongarch.lasx.xvfcmp.cle.d
    loongarch_lasx_xvfcmp_cle_s,               // llvm.loongarch.lasx.xvfcmp.cle.s
    loongarch_lasx_xvfcmp_clt_d,               // llvm.loongarch.lasx.xvfcmp.clt.d
    loongarch_lasx_xvfcmp_clt_s,               // llvm.loongarch.lasx.xvfcmp.clt.s
    loongarch_lasx_xvfcmp_cne_d,               // llvm.loongarch.lasx.xvfcmp.cne.d
    loongarch_lasx_xvfcmp_cne_s,               // llvm.loongarch.lasx.xvfcmp.cne.s
    loongarch_lasx_xvfcmp_cor_d,               // llvm.loongarch.lasx.xvfcmp.cor.d
    loongarch_lasx_xvfcmp_cor_s,               // llvm.loongarch.lasx.xvfcmp.cor.s
    loongarch_lasx_xvfcmp_cueq_d,              // llvm.loongarch.lasx.xvfcmp.cueq.d
    loongarch_lasx_xvfcmp_cueq_s,              // llvm.loongarch.lasx.xvfcmp.cueq.s
    loongarch_lasx_xvfcmp_cule_d,              // llvm.loongarch.lasx.xvfcmp.cule.d
    loongarch_lasx_xvfcmp_cule_s,              // llvm.loongarch.lasx.xvfcmp.cule.s
    loongarch_lasx_xvfcmp_cult_d,              // llvm.loongarch.lasx.xvfcmp.cult.d
    loongarch_lasx_xvfcmp_cult_s,              // llvm.loongarch.lasx.xvfcmp.cult.s
    loongarch_lasx_xvfcmp_cun_d,               // llvm.loongarch.lasx.xvfcmp.cun.d
    loongarch_lasx_xvfcmp_cun_s,               // llvm.loongarch.lasx.xvfcmp.cun.s
    loongarch_lasx_xvfcmp_cune_d,              // llvm.loongarch.lasx.xvfcmp.cune.d
    loongarch_lasx_xvfcmp_cune_s,              // llvm.loongarch.lasx.xvfcmp.cune.s
    loongarch_lasx_xvfcmp_saf_d,               // llvm.loongarch.lasx.xvfcmp.saf.d
    loongarch_lasx_xvfcmp_saf_s,               // llvm.loongarch.lasx.xvfcmp.saf.s
    loongarch_lasx_xvfcmp_seq_d,               // llvm.loongarch.lasx.xvfcmp.seq.d
    loongarch_lasx_xvfcmp_seq_s,               // llvm.loongarch.lasx.xvfcmp.seq.s
    loongarch_lasx_xvfcmp_sle_d,               // llvm.loongarch.lasx.xvfcmp.sle.d
    loongarch_lasx_xvfcmp_sle_s,               // llvm.loongarch.lasx.xvfcmp.sle.s
    loongarch_lasx_xvfcmp_slt_d,               // llvm.loongarch.lasx.xvfcmp.slt.d
    loongarch_lasx_xvfcmp_slt_s,               // llvm.loongarch.lasx.xvfcmp.slt.s
    loongarch_lasx_xvfcmp_sne_d,               // llvm.loongarch.lasx.xvfcmp.sne.d
    loongarch_lasx_xvfcmp_sne_s,               // llvm.loongarch.lasx.xvfcmp.sne.s
    loongarch_lasx_xvfcmp_sor_d,               // llvm.loongarch.lasx.xvfcmp.sor.d
    loongarch_lasx_xvfcmp_sor_s,               // llvm.loongarch.lasx.xvfcmp.sor.s
    loongarch_lasx_xvfcmp_sueq_d,              // llvm.loongarch.lasx.xvfcmp.sueq.d
    loongarch_lasx_xvfcmp_sueq_s,              // llvm.loongarch.lasx.xvfcmp.sueq.s
    loongarch_lasx_xvfcmp_sule_d,              // llvm.loongarch.lasx.xvfcmp.sule.d
    loongarch_lasx_xvfcmp_sule_s,              // llvm.loongarch.lasx.xvfcmp.sule.s
    loongarch_lasx_xvfcmp_sult_d,              // llvm.loongarch.lasx.xvfcmp.sult.d
    loongarch_lasx_xvfcmp_sult_s,              // llvm.loongarch.lasx.xvfcmp.sult.s
    loongarch_lasx_xvfcmp_sun_d,               // llvm.loongarch.lasx.xvfcmp.sun.d
    loongarch_lasx_xvfcmp_sun_s,               // llvm.loongarch.lasx.xvfcmp.sun.s
    loongarch_lasx_xvfcmp_sune_d,              // llvm.loongarch.lasx.xvfcmp.sune.d
    loongarch_lasx_xvfcmp_sune_s,              // llvm.loongarch.lasx.xvfcmp.sune.s
    loongarch_lasx_xvfcvt_h_s,                 // llvm.loongarch.lasx.xvfcvt.h.s
    loongarch_lasx_xvfcvt_s_d,                 // llvm.loongarch.lasx.xvfcvt.s.d
    loongarch_lasx_xvfcvth_d_s,                // llvm.loongarch.lasx.xvfcvth.d.s
    loongarch_lasx_xvfcvth_s_h,                // llvm.loongarch.lasx.xvfcvth.s.h
    loongarch_lasx_xvfcvtl_d_s,                // llvm.loongarch.lasx.xvfcvtl.d.s
    loongarch_lasx_xvfcvtl_s_h,                // llvm.loongarch.lasx.xvfcvtl.s.h
    loongarch_lasx_xvfdiv_d,                   // llvm.loongarch.lasx.xvfdiv.d
    loongarch_lasx_xvfdiv_s,                   // llvm.loongarch.lasx.xvfdiv.s
    loongarch_lasx_xvffint_d_l,                // llvm.loongarch.lasx.xvffint.d.l
    loongarch_lasx_xvffint_d_lu,               // llvm.loongarch.lasx.xvffint.d.lu
    loongarch_lasx_xvffint_s_l,                // llvm.loongarch.lasx.xvffint.s.l
    loongarch_lasx_xvffint_s_w,                // llvm.loongarch.lasx.xvffint.s.w
    loongarch_lasx_xvffint_s_wu,               // llvm.loongarch.lasx.xvffint.s.wu
    loongarch_lasx_xvffinth_d_w,               // llvm.loongarch.lasx.xvffinth.d.w
    loongarch_lasx_xvffintl_d_w,               // llvm.loongarch.lasx.xvffintl.d.w
    loongarch_lasx_xvflogb_d,                  // llvm.loongarch.lasx.xvflogb.d
    loongarch_lasx_xvflogb_s,                  // llvm.loongarch.lasx.xvflogb.s
    loongarch_lasx_xvfmadd_d,                  // llvm.loongarch.lasx.xvfmadd.d
    loongarch_lasx_xvfmadd_s,                  // llvm.loongarch.lasx.xvfmadd.s
    loongarch_lasx_xvfmax_d,                   // llvm.loongarch.lasx.xvfmax.d
    loongarch_lasx_xvfmax_s,                   // llvm.loongarch.lasx.xvfmax.s
    loongarch_lasx_xvfmaxa_d,                  // llvm.loongarch.lasx.xvfmaxa.d
    loongarch_lasx_xvfmaxa_s,                  // llvm.loongarch.lasx.xvfmaxa.s
    loongarch_lasx_xvfmin_d,                   // llvm.loongarch.lasx.xvfmin.d
    loongarch_lasx_xvfmin_s,                   // llvm.loongarch.lasx.xvfmin.s
    loongarch_lasx_xvfmina_d,                  // llvm.loongarch.lasx.xvfmina.d
    loongarch_lasx_xvfmina_s,                  // llvm.loongarch.lasx.xvfmina.s
    loongarch_lasx_xvfmsub_d,                  // llvm.loongarch.lasx.xvfmsub.d
    loongarch_lasx_xvfmsub_s,                  // llvm.loongarch.lasx.xvfmsub.s
    loongarch_lasx_xvfmul_d,                   // llvm.loongarch.lasx.xvfmul.d
    loongarch_lasx_xvfmul_s,                   // llvm.loongarch.lasx.xvfmul.s
    loongarch_lasx_xvfnmadd_d,                 // llvm.loongarch.lasx.xvfnmadd.d
    loongarch_lasx_xvfnmadd_s,                 // llvm.loongarch.lasx.xvfnmadd.s
    loongarch_lasx_xvfnmsub_d,                 // llvm.loongarch.lasx.xvfnmsub.d
    loongarch_lasx_xvfnmsub_s,                 // llvm.loongarch.lasx.xvfnmsub.s
    loongarch_lasx_xvfrecip_d,                 // llvm.loongarch.lasx.xvfrecip.d
    loongarch_lasx_xvfrecip_s,                 // llvm.loongarch.lasx.xvfrecip.s
    loongarch_lasx_xvfrecipe_d,                // llvm.loongarch.lasx.xvfrecipe.d
    loongarch_lasx_xvfrecipe_s,                // llvm.loongarch.lasx.xvfrecipe.s
    loongarch_lasx_xvfrint_d,                  // llvm.loongarch.lasx.xvfrint.d
    loongarch_lasx_xvfrint_s,                  // llvm.loongarch.lasx.xvfrint.s
    loongarch_lasx_xvfrintrm_d,                // llvm.loongarch.lasx.xvfrintrm.d
    loongarch_lasx_xvfrintrm_s,                // llvm.loongarch.lasx.xvfrintrm.s
    loongarch_lasx_xvfrintrne_d,               // llvm.loongarch.lasx.xvfrintrne.d
    loongarch_lasx_xvfrintrne_s,               // llvm.loongarch.lasx.xvfrintrne.s
    loongarch_lasx_xvfrintrp_d,                // llvm.loongarch.lasx.xvfrintrp.d
    loongarch_lasx_xvfrintrp_s,                // llvm.loongarch.lasx.xvfrintrp.s
    loongarch_lasx_xvfrintrz_d,                // llvm.loongarch.lasx.xvfrintrz.d
    loongarch_lasx_xvfrintrz_s,                // llvm.loongarch.lasx.xvfrintrz.s
    loongarch_lasx_xvfrsqrt_d,                 // llvm.loongarch.lasx.xvfrsqrt.d
    loongarch_lasx_xvfrsqrt_s,                 // llvm.loongarch.lasx.xvfrsqrt.s
    loongarch_lasx_xvfrsqrte_d,                // llvm.loongarch.lasx.xvfrsqrte.d
    loongarch_lasx_xvfrsqrte_s,                // llvm.loongarch.lasx.xvfrsqrte.s
    loongarch_lasx_xvfrstp_b,                  // llvm.loongarch.lasx.xvfrstp.b
    loongarch_lasx_xvfrstp_h,                  // llvm.loongarch.lasx.xvfrstp.h
    loongarch_lasx_xvfrstpi_b,                 // llvm.loongarch.lasx.xvfrstpi.b
    loongarch_lasx_xvfrstpi_h,                 // llvm.loongarch.lasx.xvfrstpi.h
    loongarch_lasx_xvfsqrt_d,                  // llvm.loongarch.lasx.xvfsqrt.d
    loongarch_lasx_xvfsqrt_s,                  // llvm.loongarch.lasx.xvfsqrt.s
    loongarch_lasx_xvfsub_d,                   // llvm.loongarch.lasx.xvfsub.d
    loongarch_lasx_xvfsub_s,                   // llvm.loongarch.lasx.xvfsub.s
    loongarch_lasx_xvftint_l_d,                // llvm.loongarch.lasx.xvftint.l.d
    loongarch_lasx_xvftint_lu_d,               // llvm.loongarch.lasx.xvftint.lu.d
    loongarch_lasx_xvftint_w_d,                // llvm.loongarch.lasx.xvftint.w.d
    loongarch_lasx_xvftint_w_s,                // llvm.loongarch.lasx.xvftint.w.s
    loongarch_lasx_xvftint_wu_s,               // llvm.loongarch.lasx.xvftint.wu.s
    loongarch_lasx_xvftinth_l_s,               // llvm.loongarch.lasx.xvftinth.l.s
    loongarch_lasx_xvftintl_l_s,               // llvm.loongarch.lasx.xvftintl.l.s
    loongarch_lasx_xvftintrm_l_d,              // llvm.loongarch.lasx.xvftintrm.l.d
    loongarch_lasx_xvftintrm_w_d,              // llvm.loongarch.lasx.xvftintrm.w.d
    loongarch_lasx_xvftintrm_w_s,              // llvm.loongarch.lasx.xvftintrm.w.s
    loongarch_lasx_xvftintrmh_l_s,             // llvm.loongarch.lasx.xvftintrmh.l.s
    loongarch_lasx_xvftintrml_l_s,             // llvm.loongarch.lasx.xvftintrml.l.s
    loongarch_lasx_xvftintrne_l_d,             // llvm.loongarch.lasx.xvftintrne.l.d
    loongarch_lasx_xvftintrne_w_d,             // llvm.loongarch.lasx.xvftintrne.w.d
    loongarch_lasx_xvftintrne_w_s,             // llvm.loongarch.lasx.xvftintrne.w.s
    loongarch_lasx_xvftintrneh_l_s,            // llvm.loongarch.lasx.xvftintrneh.l.s
    loongarch_lasx_xvftintrnel_l_s,            // llvm.loongarch.lasx.xvftintrnel.l.s
    loongarch_lasx_xvftintrp_l_d,              // llvm.loongarch.lasx.xvftintrp.l.d
    loongarch_lasx_xvftintrp_w_d,              // llvm.loongarch.lasx.xvftintrp.w.d
    loongarch_lasx_xvftintrp_w_s,              // llvm.loongarch.lasx.xvftintrp.w.s
    loongarch_lasx_xvftintrph_l_s,             // llvm.loongarch.lasx.xvftintrph.l.s
    loongarch_lasx_xvftintrpl_l_s,             // llvm.loongarch.lasx.xvftintrpl.l.s
    loongarch_lasx_xvftintrz_l_d,              // llvm.loongarch.lasx.xvftintrz.l.d
    loongarch_lasx_xvftintrz_lu_d,             // llvm.loongarch.lasx.xvftintrz.lu.d
    loongarch_lasx_xvftintrz_w_d,              // llvm.loongarch.lasx.xvftintrz.w.d
    loongarch_lasx_xvftintrz_w_s,              // llvm.loongarch.lasx.xvftintrz.w.s
    loongarch_lasx_xvftintrz_wu_s,             // llvm.loongarch.lasx.xvftintrz.wu.s
    loongarch_lasx_xvftintrzh_l_s,             // llvm.loongarch.lasx.xvftintrzh.l.s
    loongarch_lasx_xvftintrzl_l_s,             // llvm.loongarch.lasx.xvftintrzl.l.s
    loongarch_lasx_xvhaddw_d_w,                // llvm.loongarch.lasx.xvhaddw.d.w
    loongarch_lasx_xvhaddw_du_wu,              // llvm.loongarch.lasx.xvhaddw.du.wu
    loongarch_lasx_xvhaddw_h_b,                // llvm.loongarch.lasx.xvhaddw.h.b
    loongarch_lasx_xvhaddw_hu_bu,              // llvm.loongarch.lasx.xvhaddw.hu.bu
    loongarch_lasx_xvhaddw_q_d,                // llvm.loongarch.lasx.xvhaddw.q.d
    loongarch_lasx_xvhaddw_qu_du,              // llvm.loongarch.lasx.xvhaddw.qu.du
    loongarch_lasx_xvhaddw_w_h,                // llvm.loongarch.lasx.xvhaddw.w.h
    loongarch_lasx_xvhaddw_wu_hu,              // llvm.loongarch.lasx.xvhaddw.wu.hu
    loongarch_lasx_xvhsubw_d_w,                // llvm.loongarch.lasx.xvhsubw.d.w
    loongarch_lasx_xvhsubw_du_wu,              // llvm.loongarch.lasx.xvhsubw.du.wu
    loongarch_lasx_xvhsubw_h_b,                // llvm.loongarch.lasx.xvhsubw.h.b
    loongarch_lasx_xvhsubw_hu_bu,              // llvm.loongarch.lasx.xvhsubw.hu.bu
    loongarch_lasx_xvhsubw_q_d,                // llvm.loongarch.lasx.xvhsubw.q.d
    loongarch_lasx_xvhsubw_qu_du,              // llvm.loongarch.lasx.xvhsubw.qu.du
    loongarch_lasx_xvhsubw_w_h,                // llvm.loongarch.lasx.xvhsubw.w.h
    loongarch_lasx_xvhsubw_wu_hu,              // llvm.loongarch.lasx.xvhsubw.wu.hu
    loongarch_lasx_xvilvh_b,                   // llvm.loongarch.lasx.xvilvh.b
    loongarch_lasx_xvilvh_d,                   // llvm.loongarch.lasx.xvilvh.d
    loongarch_lasx_xvilvh_h,                   // llvm.loongarch.lasx.xvilvh.h
    loongarch_lasx_xvilvh_w,                   // llvm.loongarch.lasx.xvilvh.w
    loongarch_lasx_xvilvl_b,                   // llvm.loongarch.lasx.xvilvl.b
    loongarch_lasx_xvilvl_d,                   // llvm.loongarch.lasx.xvilvl.d
    loongarch_lasx_xvilvl_h,                   // llvm.loongarch.lasx.xvilvl.h
    loongarch_lasx_xvilvl_w,                   // llvm.loongarch.lasx.xvilvl.w
    loongarch_lasx_xvinsgr2vr_d,               // llvm.loongarch.lasx.xvinsgr2vr.d
    loongarch_lasx_xvinsgr2vr_w,               // llvm.loongarch.lasx.xvinsgr2vr.w
    loongarch_lasx_xvinsve0_d,                 // llvm.loongarch.lasx.xvinsve0.d
    loongarch_lasx_xvinsve0_w,                 // llvm.loongarch.lasx.xvinsve0.w
    loongarch_lasx_xvld,                       // llvm.loongarch.lasx.xvld
    loongarch_lasx_xvldi,                      // llvm.loongarch.lasx.xvldi
    loongarch_lasx_xvldrepl_b,                 // llvm.loongarch.lasx.xvldrepl.b
    loongarch_lasx_xvldrepl_d,                 // llvm.loongarch.lasx.xvldrepl.d
    loongarch_lasx_xvldrepl_h,                 // llvm.loongarch.lasx.xvldrepl.h
    loongarch_lasx_xvldrepl_w,                 // llvm.loongarch.lasx.xvldrepl.w
    loongarch_lasx_xvldx,                      // llvm.loongarch.lasx.xvldx
    loongarch_lasx_xvmadd_b,                   // llvm.loongarch.lasx.xvmadd.b
    loongarch_lasx_xvmadd_d,                   // llvm.loongarch.lasx.xvmadd.d
    loongarch_lasx_xvmadd_h,                   // llvm.loongarch.lasx.xvmadd.h
    loongarch_lasx_xvmadd_w,                   // llvm.loongarch.lasx.xvmadd.w
    loongarch_lasx_xvmaddwev_d_w,              // llvm.loongarch.lasx.xvmaddwev.d.w
    loongarch_lasx_xvmaddwev_d_wu,             // llvm.loongarch.lasx.xvmaddwev.d.wu
    loongarch_lasx_xvmaddwev_d_wu_w,           // llvm.loongarch.lasx.xvmaddwev.d.wu.w
    loongarch_lasx_xvmaddwev_h_b,              // llvm.loongarch.lasx.xvmaddwev.h.b
    loongarch_lasx_xvmaddwev_h_bu,             // llvm.loongarch.lasx.xvmaddwev.h.bu
    loongarch_lasx_xvmaddwev_h_bu_b,           // llvm.loongarch.lasx.xvmaddwev.h.bu.b
    loongarch_lasx_xvmaddwev_q_d,              // llvm.loongarch.lasx.xvmaddwev.q.d
    loongarch_lasx_xvmaddwev_q_du,             // llvm.loongarch.lasx.xvmaddwev.q.du
    loongarch_lasx_xvmaddwev_q_du_d,           // llvm.loongarch.lasx.xvmaddwev.q.du.d
    loongarch_lasx_xvmaddwev_w_h,              // llvm.loongarch.lasx.xvmaddwev.w.h
    loongarch_lasx_xvmaddwev_w_hu,             // llvm.loongarch.lasx.xvmaddwev.w.hu
    loongarch_lasx_xvmaddwev_w_hu_h,           // llvm.loongarch.lasx.xvmaddwev.w.hu.h
    loongarch_lasx_xvmaddwod_d_w,              // llvm.loongarch.lasx.xvmaddwod.d.w
    loongarch_lasx_xvmaddwod_d_wu,             // llvm.loongarch.lasx.xvmaddwod.d.wu
    loongarch_lasx_xvmaddwod_d_wu_w,           // llvm.loongarch.lasx.xvmaddwod.d.wu.w
    loongarch_lasx_xvmaddwod_h_b,              // llvm.loongarch.lasx.xvmaddwod.h.b
    loongarch_lasx_xvmaddwod_h_bu,             // llvm.loongarch.lasx.xvmaddwod.h.bu
    loongarch_lasx_xvmaddwod_h_bu_b,           // llvm.loongarch.lasx.xvmaddwod.h.bu.b
    loongarch_lasx_xvmaddwod_q_d,              // llvm.loongarch.lasx.xvmaddwod.q.d
    loongarch_lasx_xvmaddwod_q_du,             // llvm.loongarch.lasx.xvmaddwod.q.du
    loongarch_lasx_xvmaddwod_q_du_d,           // llvm.loongarch.lasx.xvmaddwod.q.du.d
    loongarch_lasx_xvmaddwod_w_h,              // llvm.loongarch.lasx.xvmaddwod.w.h
    loongarch_lasx_xvmaddwod_w_hu,             // llvm.loongarch.lasx.xvmaddwod.w.hu
    loongarch_lasx_xvmaddwod_w_hu_h,           // llvm.loongarch.lasx.xvmaddwod.w.hu.h
    loongarch_lasx_xvmax_b,                    // llvm.loongarch.lasx.xvmax.b
    loongarch_lasx_xvmax_bu,                   // llvm.loongarch.lasx.xvmax.bu
    loongarch_lasx_xvmax_d,                    // llvm.loongarch.lasx.xvmax.d
    loongarch_lasx_xvmax_du,                   // llvm.loongarch.lasx.xvmax.du
    loongarch_lasx_xvmax_h,                    // llvm.loongarch.lasx.xvmax.h
    loongarch_lasx_xvmax_hu,                   // llvm.loongarch.lasx.xvmax.hu
    loongarch_lasx_xvmax_w,                    // llvm.loongarch.lasx.xvmax.w
    loongarch_lasx_xvmax_wu,                   // llvm.loongarch.lasx.xvmax.wu
    loongarch_lasx_xvmaxi_b,                   // llvm.loongarch.lasx.xvmaxi.b
    loongarch_lasx_xvmaxi_bu,                  // llvm.loongarch.lasx.xvmaxi.bu
    loongarch_lasx_xvmaxi_d,                   // llvm.loongarch.lasx.xvmaxi.d
    loongarch_lasx_xvmaxi_du,                  // llvm.loongarch.lasx.xvmaxi.du
    loongarch_lasx_xvmaxi_h,                   // llvm.loongarch.lasx.xvmaxi.h
    loongarch_lasx_xvmaxi_hu,                  // llvm.loongarch.lasx.xvmaxi.hu
    loongarch_lasx_xvmaxi_w,                   // llvm.loongarch.lasx.xvmaxi.w
    loongarch_lasx_xvmaxi_wu,                  // llvm.loongarch.lasx.xvmaxi.wu
    loongarch_lasx_xvmin_b,                    // llvm.loongarch.lasx.xvmin.b
    loongarch_lasx_xvmin_bu,                   // llvm.loongarch.lasx.xvmin.bu
    loongarch_lasx_xvmin_d,                    // llvm.loongarch.lasx.xvmin.d
    loongarch_lasx_xvmin_du,                   // llvm.loongarch.lasx.xvmin.du
    loongarch_lasx_xvmin_h,                    // llvm.loongarch.lasx.xvmin.h
    loongarch_lasx_xvmin_hu,                   // llvm.loongarch.lasx.xvmin.hu
    loongarch_lasx_xvmin_w,                    // llvm.loongarch.lasx.xvmin.w
    loongarch_lasx_xvmin_wu,                   // llvm.loongarch.lasx.xvmin.wu
    loongarch_lasx_xvmini_b,                   // llvm.loongarch.lasx.xvmini.b
    loongarch_lasx_xvmini_bu,                  // llvm.loongarch.lasx.xvmini.bu
    loongarch_lasx_xvmini_d,                   // llvm.loongarch.lasx.xvmini.d
    loongarch_lasx_xvmini_du,                  // llvm.loongarch.lasx.xvmini.du
    loongarch_lasx_xvmini_h,                   // llvm.loongarch.lasx.xvmini.h
    loongarch_lasx_xvmini_hu,                  // llvm.loongarch.lasx.xvmini.hu
    loongarch_lasx_xvmini_w,                   // llvm.loongarch.lasx.xvmini.w
    loongarch_lasx_xvmini_wu,                  // llvm.loongarch.lasx.xvmini.wu
    loongarch_lasx_xvmod_b,                    // llvm.loongarch.lasx.xvmod.b
    loongarch_lasx_xvmod_bu,                   // llvm.loongarch.lasx.xvmod.bu
    loongarch_lasx_xvmod_d,                    // llvm.loongarch.lasx.xvmod.d
    loongarch_lasx_xvmod_du,                   // llvm.loongarch.lasx.xvmod.du
    loongarch_lasx_xvmod_h,                    // llvm.loongarch.lasx.xvmod.h
    loongarch_lasx_xvmod_hu,                   // llvm.loongarch.lasx.xvmod.hu
    loongarch_lasx_xvmod_w,                    // llvm.loongarch.lasx.xvmod.w
    loongarch_lasx_xvmod_wu,                   // llvm.loongarch.lasx.xvmod.wu
    loongarch_lasx_xvmskgez_b,                 // llvm.loongarch.lasx.xvmskgez.b
    loongarch_lasx_xvmskltz_b,                 // llvm.loongarch.lasx.xvmskltz.b
    loongarch_lasx_xvmskltz_d,                 // llvm.loongarch.lasx.xvmskltz.d
    loongarch_lasx_xvmskltz_h,                 // llvm.loongarch.lasx.xvmskltz.h
    loongarch_lasx_xvmskltz_w,                 // llvm.loongarch.lasx.xvmskltz.w
    loongarch_lasx_xvmsknz_b,                  // llvm.loongarch.lasx.xvmsknz.b
    loongarch_lasx_xvmsub_b,                   // llvm.loongarch.lasx.xvmsub.b
    loongarch_lasx_xvmsub_d,                   // llvm.loongarch.lasx.xvmsub.d
    loongarch_lasx_xvmsub_h,                   // llvm.loongarch.lasx.xvmsub.h
    loongarch_lasx_xvmsub_w,                   // llvm.loongarch.lasx.xvmsub.w
    loongarch_lasx_xvmuh_b,                    // llvm.loongarch.lasx.xvmuh.b
    loongarch_lasx_xvmuh_bu,                   // llvm.loongarch.lasx.xvmuh.bu
    loongarch_lasx_xvmuh_d,                    // llvm.loongarch.lasx.xvmuh.d
    loongarch_lasx_xvmuh_du,                   // llvm.loongarch.lasx.xvmuh.du
    loongarch_lasx_xvmuh_h,                    // llvm.loongarch.lasx.xvmuh.h
    loongarch_lasx_xvmuh_hu,                   // llvm.loongarch.lasx.xvmuh.hu
    loongarch_lasx_xvmuh_w,                    // llvm.loongarch.lasx.xvmuh.w
    loongarch_lasx_xvmuh_wu,                   // llvm.loongarch.lasx.xvmuh.wu
    loongarch_lasx_xvmul_b,                    // llvm.loongarch.lasx.xvmul.b
    loongarch_lasx_xvmul_d,                    // llvm.loongarch.lasx.xvmul.d
    loongarch_lasx_xvmul_h,                    // llvm.loongarch.lasx.xvmul.h
    loongarch_lasx_xvmul_w,                    // llvm.loongarch.lasx.xvmul.w
    loongarch_lasx_xvmulwev_d_w,               // llvm.loongarch.lasx.xvmulwev.d.w
    loongarch_lasx_xvmulwev_d_wu,              // llvm.loongarch.lasx.xvmulwev.d.wu
    loongarch_lasx_xvmulwev_d_wu_w,            // llvm.loongarch.lasx.xvmulwev.d.wu.w
    loongarch_lasx_xvmulwev_h_b,               // llvm.loongarch.lasx.xvmulwev.h.b
    loongarch_lasx_xvmulwev_h_bu,              // llvm.loongarch.lasx.xvmulwev.h.bu
    loongarch_lasx_xvmulwev_h_bu_b,            // llvm.loongarch.lasx.xvmulwev.h.bu.b
    loongarch_lasx_xvmulwev_q_d,               // llvm.loongarch.lasx.xvmulwev.q.d
    loongarch_lasx_xvmulwev_q_du,              // llvm.loongarch.lasx.xvmulwev.q.du
    loongarch_lasx_xvmulwev_q_du_d,            // llvm.loongarch.lasx.xvmulwev.q.du.d
    loongarch_lasx_xvmulwev_w_h,               // llvm.loongarch.lasx.xvmulwev.w.h
    loongarch_lasx_xvmulwev_w_hu,              // llvm.loongarch.lasx.xvmulwev.w.hu
    loongarch_lasx_xvmulwev_w_hu_h,            // llvm.loongarch.lasx.xvmulwev.w.hu.h
    loongarch_lasx_xvmulwod_d_w,               // llvm.loongarch.lasx.xvmulwod.d.w
    loongarch_lasx_xvmulwod_d_wu,              // llvm.loongarch.lasx.xvmulwod.d.wu
    loongarch_lasx_xvmulwod_d_wu_w,            // llvm.loongarch.lasx.xvmulwod.d.wu.w
    loongarch_lasx_xvmulwod_h_b,               // llvm.loongarch.lasx.xvmulwod.h.b
    loongarch_lasx_xvmulwod_h_bu,              // llvm.loongarch.lasx.xvmulwod.h.bu
    loongarch_lasx_xvmulwod_h_bu_b,            // llvm.loongarch.lasx.xvmulwod.h.bu.b
    loongarch_lasx_xvmulwod_q_d,               // llvm.loongarch.lasx.xvmulwod.q.d
    loongarch_lasx_xvmulwod_q_du,              // llvm.loongarch.lasx.xvmulwod.q.du
    loongarch_lasx_xvmulwod_q_du_d,            // llvm.loongarch.lasx.xvmulwod.q.du.d
    loongarch_lasx_xvmulwod_w_h,               // llvm.loongarch.lasx.xvmulwod.w.h
    loongarch_lasx_xvmulwod_w_hu,              // llvm.loongarch.lasx.xvmulwod.w.hu
    loongarch_lasx_xvmulwod_w_hu_h,            // llvm.loongarch.lasx.xvmulwod.w.hu.h
    loongarch_lasx_xvneg_b,                    // llvm.loongarch.lasx.xvneg.b
    loongarch_lasx_xvneg_d,                    // llvm.loongarch.lasx.xvneg.d
    loongarch_lasx_xvneg_h,                    // llvm.loongarch.lasx.xvneg.h
    loongarch_lasx_xvneg_w,                    // llvm.loongarch.lasx.xvneg.w
    loongarch_lasx_xvnor_v,                    // llvm.loongarch.lasx.xvnor.v
    loongarch_lasx_xvnori_b,                   // llvm.loongarch.lasx.xvnori.b
    loongarch_lasx_xvor_v,                     // llvm.loongarch.lasx.xvor.v
    loongarch_lasx_xvori_b,                    // llvm.loongarch.lasx.xvori.b
    loongarch_lasx_xvorn_v,                    // llvm.loongarch.lasx.xvorn.v
    loongarch_lasx_xvpackev_b,                 // llvm.loongarch.lasx.xvpackev.b
    loongarch_lasx_xvpackev_d,                 // llvm.loongarch.lasx.xvpackev.d
    loongarch_lasx_xvpackev_h,                 // llvm.loongarch.lasx.xvpackev.h
    loongarch_lasx_xvpackev_w,                 // llvm.loongarch.lasx.xvpackev.w
    loongarch_lasx_xvpackod_b,                 // llvm.loongarch.lasx.xvpackod.b
    loongarch_lasx_xvpackod_d,                 // llvm.loongarch.lasx.xvpackod.d
    loongarch_lasx_xvpackod_h,                 // llvm.loongarch.lasx.xvpackod.h
    loongarch_lasx_xvpackod_w,                 // llvm.loongarch.lasx.xvpackod.w
    loongarch_lasx_xvpcnt_b,                   // llvm.loongarch.lasx.xvpcnt.b
    loongarch_lasx_xvpcnt_d,                   // llvm.loongarch.lasx.xvpcnt.d
    loongarch_lasx_xvpcnt_h,                   // llvm.loongarch.lasx.xvpcnt.h
    loongarch_lasx_xvpcnt_w,                   // llvm.loongarch.lasx.xvpcnt.w
    loongarch_lasx_xvperm_w,                   // llvm.loongarch.lasx.xvperm.w
    loongarch_lasx_xvpermi_d,                  // llvm.loongarch.lasx.xvpermi.d
    loongarch_lasx_xvpermi_q,                  // llvm.loongarch.lasx.xvpermi.q
    loongarch_lasx_xvpermi_w,                  // llvm.loongarch.lasx.xvpermi.w
    loongarch_lasx_xvpickev_b,                 // llvm.loongarch.lasx.xvpickev.b
    loongarch_lasx_xvpickev_d,                 // llvm.loongarch.lasx.xvpickev.d
    loongarch_lasx_xvpickev_h,                 // llvm.loongarch.lasx.xvpickev.h
    loongarch_lasx_xvpickev_w,                 // llvm.loongarch.lasx.xvpickev.w
    loongarch_lasx_xvpickod_b,                 // llvm.loongarch.lasx.xvpickod.b
    loongarch_lasx_xvpickod_d,                 // llvm.loongarch.lasx.xvpickod.d
    loongarch_lasx_xvpickod_h,                 // llvm.loongarch.lasx.xvpickod.h
    loongarch_lasx_xvpickod_w,                 // llvm.loongarch.lasx.xvpickod.w
    loongarch_lasx_xvpickve_d,                 // llvm.loongarch.lasx.xvpickve.d
    loongarch_lasx_xvpickve_d_f,               // llvm.loongarch.lasx.xvpickve.d.f
    loongarch_lasx_xvpickve_w,                 // llvm.loongarch.lasx.xvpickve.w
    loongarch_lasx_xvpickve_w_f,               // llvm.loongarch.lasx.xvpickve.w.f
    loongarch_lasx_xvpickve2gr_d,              // llvm.loongarch.lasx.xvpickve2gr.d
    loongarch_lasx_xvpickve2gr_du,             // llvm.loongarch.lasx.xvpickve2gr.du
    loongarch_lasx_xvpickve2gr_w,              // llvm.loongarch.lasx.xvpickve2gr.w
    loongarch_lasx_xvpickve2gr_wu,             // llvm.loongarch.lasx.xvpickve2gr.wu
    loongarch_lasx_xvrepl128vei_b,             // llvm.loongarch.lasx.xvrepl128vei.b
    loongarch_lasx_xvrepl128vei_d,             // llvm.loongarch.lasx.xvrepl128vei.d
    loongarch_lasx_xvrepl128vei_h,             // llvm.loongarch.lasx.xvrepl128vei.h
    loongarch_lasx_xvrepl128vei_w,             // llvm.loongarch.lasx.xvrepl128vei.w
    loongarch_lasx_xvreplgr2vr_b,              // llvm.loongarch.lasx.xvreplgr2vr.b
    loongarch_lasx_xvreplgr2vr_d,              // llvm.loongarch.lasx.xvreplgr2vr.d
    loongarch_lasx_xvreplgr2vr_h,              // llvm.loongarch.lasx.xvreplgr2vr.h
    loongarch_lasx_xvreplgr2vr_w,              // llvm.loongarch.lasx.xvreplgr2vr.w
    loongarch_lasx_xvrepli_b,                  // llvm.loongarch.lasx.xvrepli.b
    loongarch_lasx_xvrepli_d,                  // llvm.loongarch.lasx.xvrepli.d
    loongarch_lasx_xvrepli_h,                  // llvm.loongarch.lasx.xvrepli.h
    loongarch_lasx_xvrepli_w,                  // llvm.loongarch.lasx.xvrepli.w
    loongarch_lasx_xvreplve_b,                 // llvm.loongarch.lasx.xvreplve.b
    loongarch_lasx_xvreplve_d,                 // llvm.loongarch.lasx.xvreplve.d
    loongarch_lasx_xvreplve_h,                 // llvm.loongarch.lasx.xvreplve.h
    loongarch_lasx_xvreplve_w,                 // llvm.loongarch.lasx.xvreplve.w
    loongarch_lasx_xvreplve0_b,                // llvm.loongarch.lasx.xvreplve0.b
    loongarch_lasx_xvreplve0_d,                // llvm.loongarch.lasx.xvreplve0.d
    loongarch_lasx_xvreplve0_h,                // llvm.loongarch.lasx.xvreplve0.h
    loongarch_lasx_xvreplve0_q,                // llvm.loongarch.lasx.xvreplve0.q
    loongarch_lasx_xvreplve0_w,                // llvm.loongarch.lasx.xvreplve0.w
    loongarch_lasx_xvrotr_b,                   // llvm.loongarch.lasx.xvrotr.b
    loongarch_lasx_xvrotr_d,                   // llvm.loongarch.lasx.xvrotr.d
    loongarch_lasx_xvrotr_h,                   // llvm.loongarch.lasx.xvrotr.h
    loongarch_lasx_xvrotr_w,                   // llvm.loongarch.lasx.xvrotr.w
    loongarch_lasx_xvrotri_b,                  // llvm.loongarch.lasx.xvrotri.b
    loongarch_lasx_xvrotri_d,                  // llvm.loongarch.lasx.xvrotri.d
    loongarch_lasx_xvrotri_h,                  // llvm.loongarch.lasx.xvrotri.h
    loongarch_lasx_xvrotri_w,                  // llvm.loongarch.lasx.xvrotri.w
    loongarch_lasx_xvsadd_b,                   // llvm.loongarch.lasx.xvsadd.b
    loongarch_lasx_xvsadd_bu,                  // llvm.loongarch.lasx.xvsadd.bu
    loongarch_lasx_xvsadd_d,                   // llvm.loongarch.lasx.xvsadd.d
    loongarch_lasx_xvsadd_du,                  // llvm.loongarch.lasx.xvsadd.du
    loongarch_lasx_xvsadd_h,                   // llvm.loongarch.lasx.xvsadd.h
    loongarch_lasx_xvsadd_hu,                  // llvm.loongarch.lasx.xvsadd.hu
    loongarch_lasx_xvsadd_w,                   // llvm.loongarch.lasx.xvsadd.w
    loongarch_lasx_xvsadd_wu,                  // llvm.loongarch.lasx.xvsadd.wu
    loongarch_lasx_xvsat_b,                    // llvm.loongarch.lasx.xvsat.b
    loongarch_lasx_xvsat_bu,                   // llvm.loongarch.lasx.xvsat.bu
    loongarch_lasx_xvsat_d,                    // llvm.loongarch.lasx.xvsat.d
    loongarch_lasx_xvsat_du,                   // llvm.loongarch.lasx.xvsat.du
    loongarch_lasx_xvsat_h,                    // llvm.loongarch.lasx.xvsat.h
    loongarch_lasx_xvsat_hu,                   // llvm.loongarch.lasx.xvsat.hu
    loongarch_lasx_xvsat_w,                    // llvm.loongarch.lasx.xvsat.w
    loongarch_lasx_xvsat_wu,                   // llvm.loongarch.lasx.xvsat.wu
    loongarch_lasx_xvseq_b,                    // llvm.loongarch.lasx.xvseq.b
    loongarch_lasx_xvseq_d,                    // llvm.loongarch.lasx.xvseq.d
    loongarch_lasx_xvseq_h,                    // llvm.loongarch.lasx.xvseq.h
    loongarch_lasx_xvseq_w,                    // llvm.loongarch.lasx.xvseq.w
    loongarch_lasx_xvseqi_b,                   // llvm.loongarch.lasx.xvseqi.b
    loongarch_lasx_xvseqi_d,                   // llvm.loongarch.lasx.xvseqi.d
    loongarch_lasx_xvseqi_h,                   // llvm.loongarch.lasx.xvseqi.h
    loongarch_lasx_xvseqi_w,                   // llvm.loongarch.lasx.xvseqi.w
    loongarch_lasx_xvshuf_b,                   // llvm.loongarch.lasx.xvshuf.b
    loongarch_lasx_xvshuf_d,                   // llvm.loongarch.lasx.xvshuf.d
    loongarch_lasx_xvshuf_h,                   // llvm.loongarch.lasx.xvshuf.h
    loongarch_lasx_xvshuf_w,                   // llvm.loongarch.lasx.xvshuf.w
    loongarch_lasx_xvshuf4i_b,                 // llvm.loongarch.lasx.xvshuf4i.b
    loongarch_lasx_xvshuf4i_d,                 // llvm.loongarch.lasx.xvshuf4i.d
    loongarch_lasx_xvshuf4i_h,                 // llvm.loongarch.lasx.xvshuf4i.h
    loongarch_lasx_xvshuf4i_w,                 // llvm.loongarch.lasx.xvshuf4i.w
    loongarch_lasx_xvsigncov_b,                // llvm.loongarch.lasx.xvsigncov.b
    loongarch_lasx_xvsigncov_d,                // llvm.loongarch.lasx.xvsigncov.d
    loongarch_lasx_xvsigncov_h,                // llvm.loongarch.lasx.xvsigncov.h
    loongarch_lasx_xvsigncov_w,                // llvm.loongarch.lasx.xvsigncov.w
    loongarch_lasx_xvsle_b,                    // llvm.loongarch.lasx.xvsle.b
    loongarch_lasx_xvsle_bu,                   // llvm.loongarch.lasx.xvsle.bu
    loongarch_lasx_xvsle_d,                    // llvm.loongarch.lasx.xvsle.d
    loongarch_lasx_xvsle_du,                   // llvm.loongarch.lasx.xvsle.du
    loongarch_lasx_xvsle_h,                    // llvm.loongarch.lasx.xvsle.h
    loongarch_lasx_xvsle_hu,                   // llvm.loongarch.lasx.xvsle.hu
    loongarch_lasx_xvsle_w,                    // llvm.loongarch.lasx.xvsle.w
    loongarch_lasx_xvsle_wu,                   // llvm.loongarch.lasx.xvsle.wu
    loongarch_lasx_xvslei_b,                   // llvm.loongarch.lasx.xvslei.b
    loongarch_lasx_xvslei_bu,                  // llvm.loongarch.lasx.xvslei.bu
    loongarch_lasx_xvslei_d,                   // llvm.loongarch.lasx.xvslei.d
    loongarch_lasx_xvslei_du,                  // llvm.loongarch.lasx.xvslei.du
    loongarch_lasx_xvslei_h,                   // llvm.loongarch.lasx.xvslei.h
    loongarch_lasx_xvslei_hu,                  // llvm.loongarch.lasx.xvslei.hu
    loongarch_lasx_xvslei_w,                   // llvm.loongarch.lasx.xvslei.w
    loongarch_lasx_xvslei_wu,                  // llvm.loongarch.lasx.xvslei.wu
    loongarch_lasx_xvsll_b,                    // llvm.loongarch.lasx.xvsll.b
    loongarch_lasx_xvsll_d,                    // llvm.loongarch.lasx.xvsll.d
    loongarch_lasx_xvsll_h,                    // llvm.loongarch.lasx.xvsll.h
    loongarch_lasx_xvsll_w,                    // llvm.loongarch.lasx.xvsll.w
    loongarch_lasx_xvslli_b,                   // llvm.loongarch.lasx.xvslli.b
    loongarch_lasx_xvslli_d,                   // llvm.loongarch.lasx.xvslli.d
    loongarch_lasx_xvslli_h,                   // llvm.loongarch.lasx.xvslli.h
    loongarch_lasx_xvslli_w,                   // llvm.loongarch.lasx.xvslli.w
    loongarch_lasx_xvsllwil_d_w,               // llvm.loongarch.lasx.xvsllwil.d.w
    loongarch_lasx_xvsllwil_du_wu,             // llvm.loongarch.lasx.xvsllwil.du.wu
    loongarch_lasx_xvsllwil_h_b,               // llvm.loongarch.lasx.xvsllwil.h.b
    loongarch_lasx_xvsllwil_hu_bu,             // llvm.loongarch.lasx.xvsllwil.hu.bu
    loongarch_lasx_xvsllwil_w_h,               // llvm.loongarch.lasx.xvsllwil.w.h
    loongarch_lasx_xvsllwil_wu_hu,             // llvm.loongarch.lasx.xvsllwil.wu.hu
    loongarch_lasx_xvslt_b,                    // llvm.loongarch.lasx.xvslt.b
    loongarch_lasx_xvslt_bu,                   // llvm.loongarch.lasx.xvslt.bu
    loongarch_lasx_xvslt_d,                    // llvm.loongarch.lasx.xvslt.d
    loongarch_lasx_xvslt_du,                   // llvm.loongarch.lasx.xvslt.du
    loongarch_lasx_xvslt_h,                    // llvm.loongarch.lasx.xvslt.h
    loongarch_lasx_xvslt_hu,                   // llvm.loongarch.lasx.xvslt.hu
    loongarch_lasx_xvslt_w,                    // llvm.loongarch.lasx.xvslt.w
    loongarch_lasx_xvslt_wu,                   // llvm.loongarch.lasx.xvslt.wu
    loongarch_lasx_xvslti_b,                   // llvm.loongarch.lasx.xvslti.b
    loongarch_lasx_xvslti_bu,                  // llvm.loongarch.lasx.xvslti.bu
    loongarch_lasx_xvslti_d,                   // llvm.loongarch.lasx.xvslti.d
    loongarch_lasx_xvslti_du,                  // llvm.loongarch.lasx.xvslti.du
    loongarch_lasx_xvslti_h,                   // llvm.loongarch.lasx.xvslti.h
    loongarch_lasx_xvslti_hu,                  // llvm.loongarch.lasx.xvslti.hu
    loongarch_lasx_xvslti_w,                   // llvm.loongarch.lasx.xvslti.w
    loongarch_lasx_xvslti_wu,                  // llvm.loongarch.lasx.xvslti.wu
    loongarch_lasx_xvsra_b,                    // llvm.loongarch.lasx.xvsra.b
    loongarch_lasx_xvsra_d,                    // llvm.loongarch.lasx.xvsra.d
    loongarch_lasx_xvsra_h,                    // llvm.loongarch.lasx.xvsra.h
    loongarch_lasx_xvsra_w,                    // llvm.loongarch.lasx.xvsra.w
    loongarch_lasx_xvsrai_b,                   // llvm.loongarch.lasx.xvsrai.b
    loongarch_lasx_xvsrai_d,                   // llvm.loongarch.lasx.xvsrai.d
    loongarch_lasx_xvsrai_h,                   // llvm.loongarch.lasx.xvsrai.h
    loongarch_lasx_xvsrai_w,                   // llvm.loongarch.lasx.xvsrai.w
    loongarch_lasx_xvsran_b_h,                 // llvm.loongarch.lasx.xvsran.b.h
    loongarch_lasx_xvsran_h_w,                 // llvm.loongarch.lasx.xvsran.h.w
    loongarch_lasx_xvsran_w_d,                 // llvm.loongarch.lasx.xvsran.w.d
    loongarch_lasx_xvsrani_b_h,                // llvm.loongarch.lasx.xvsrani.b.h
    loongarch_lasx_xvsrani_d_q,                // llvm.loongarch.lasx.xvsrani.d.q
    loongarch_lasx_xvsrani_h_w,                // llvm.loongarch.lasx.xvsrani.h.w
    loongarch_lasx_xvsrani_w_d,                // llvm.loongarch.lasx.xvsrani.w.d
    loongarch_lasx_xvsrar_b,                   // llvm.loongarch.lasx.xvsrar.b
    loongarch_lasx_xvsrar_d,                   // llvm.loongarch.lasx.xvsrar.d
    loongarch_lasx_xvsrar_h,                   // llvm.loongarch.lasx.xvsrar.h
    loongarch_lasx_xvsrar_w,                   // llvm.loongarch.lasx.xvsrar.w
    loongarch_lasx_xvsrari_b,                  // llvm.loongarch.lasx.xvsrari.b
    loongarch_lasx_xvsrari_d,                  // llvm.loongarch.lasx.xvsrari.d
    loongarch_lasx_xvsrari_h,                  // llvm.loongarch.lasx.xvsrari.h
    loongarch_lasx_xvsrari_w,                  // llvm.loongarch.lasx.xvsrari.w
    loongarch_lasx_xvsrarn_b_h,                // llvm.loongarch.lasx.xvsrarn.b.h
    loongarch_lasx_xvsrarn_h_w,                // llvm.loongarch.lasx.xvsrarn.h.w
    loongarch_lasx_xvsrarn_w_d,                // llvm.loongarch.lasx.xvsrarn.w.d
    loongarch_lasx_xvsrarni_b_h,               // llvm.loongarch.lasx.xvsrarni.b.h
    loongarch_lasx_xvsrarni_d_q,               // llvm.loongarch.lasx.xvsrarni.d.q
    loongarch_lasx_xvsrarni_h_w,               // llvm.loongarch.lasx.xvsrarni.h.w
    loongarch_lasx_xvsrarni_w_d,               // llvm.loongarch.lasx.xvsrarni.w.d
    loongarch_lasx_xvsrl_b,                    // llvm.loongarch.lasx.xvsrl.b
    loongarch_lasx_xvsrl_d,                    // llvm.loongarch.lasx.xvsrl.d
    loongarch_lasx_xvsrl_h,                    // llvm.loongarch.lasx.xvsrl.h
    loongarch_lasx_xvsrl_w,                    // llvm.loongarch.lasx.xvsrl.w
    loongarch_lasx_xvsrli_b,                   // llvm.loongarch.lasx.xvsrli.b
    loongarch_lasx_xvsrli_d,                   // llvm.loongarch.lasx.xvsrli.d
    loongarch_lasx_xvsrli_h,                   // llvm.loongarch.lasx.xvsrli.h
    loongarch_lasx_xvsrli_w,                   // llvm.loongarch.lasx.xvsrli.w
    loongarch_lasx_xvsrln_b_h,                 // llvm.loongarch.lasx.xvsrln.b.h
    loongarch_lasx_xvsrln_h_w,                 // llvm.loongarch.lasx.xvsrln.h.w
    loongarch_lasx_xvsrln_w_d,                 // llvm.loongarch.lasx.xvsrln.w.d
    loongarch_lasx_xvsrlni_b_h,                // llvm.loongarch.lasx.xvsrlni.b.h
    loongarch_lasx_xvsrlni_d_q,                // llvm.loongarch.lasx.xvsrlni.d.q
    loongarch_lasx_xvsrlni_h_w,                // llvm.loongarch.lasx.xvsrlni.h.w
    loongarch_lasx_xvsrlni_w_d,                // llvm.loongarch.lasx.xvsrlni.w.d
    loongarch_lasx_xvsrlr_b,                   // llvm.loongarch.lasx.xvsrlr.b
    loongarch_lasx_xvsrlr_d,                   // llvm.loongarch.lasx.xvsrlr.d
    loongarch_lasx_xvsrlr_h,                   // llvm.loongarch.lasx.xvsrlr.h
    loongarch_lasx_xvsrlr_w,                   // llvm.loongarch.lasx.xvsrlr.w
    loongarch_lasx_xvsrlri_b,                  // llvm.loongarch.lasx.xvsrlri.b
    loongarch_lasx_xvsrlri_d,                  // llvm.loongarch.lasx.xvsrlri.d
    loongarch_lasx_xvsrlri_h,                  // llvm.loongarch.lasx.xvsrlri.h
    loongarch_lasx_xvsrlri_w,                  // llvm.loongarch.lasx.xvsrlri.w
    loongarch_lasx_xvsrlrn_b_h,                // llvm.loongarch.lasx.xvsrlrn.b.h
    loongarch_lasx_xvsrlrn_h_w,                // llvm.loongarch.lasx.xvsrlrn.h.w
    loongarch_lasx_xvsrlrn_w_d,                // llvm.loongarch.lasx.xvsrlrn.w.d
    loongarch_lasx_xvsrlrni_b_h,               // llvm.loongarch.lasx.xvsrlrni.b.h
    loongarch_lasx_xvsrlrni_d_q,               // llvm.loongarch.lasx.xvsrlrni.d.q
    loongarch_lasx_xvsrlrni_h_w,               // llvm.loongarch.lasx.xvsrlrni.h.w
    loongarch_lasx_xvsrlrni_w_d,               // llvm.loongarch.lasx.xvsrlrni.w.d
    loongarch_lasx_xvssran_b_h,                // llvm.loongarch.lasx.xvssran.b.h
    loongarch_lasx_xvssran_bu_h,               // llvm.loongarch.lasx.xvssran.bu.h
    loongarch_lasx_xvssran_h_w,                // llvm.loongarch.lasx.xvssran.h.w
    loongarch_lasx_xvssran_hu_w,               // llvm.loongarch.lasx.xvssran.hu.w
    loongarch_lasx_xvssran_w_d,                // llvm.loongarch.lasx.xvssran.w.d
    loongarch_lasx_xvssran_wu_d,               // llvm.loongarch.lasx.xvssran.wu.d
    loongarch_lasx_xvssrani_b_h,               // llvm.loongarch.lasx.xvssrani.b.h
    loongarch_lasx_xvssrani_bu_h,              // llvm.loongarch.lasx.xvssrani.bu.h
    loongarch_lasx_xvssrani_d_q,               // llvm.loongarch.lasx.xvssrani.d.q
    loongarch_lasx_xvssrani_du_q,              // llvm.loongarch.lasx.xvssrani.du.q
    loongarch_lasx_xvssrani_h_w,               // llvm.loongarch.lasx.xvssrani.h.w
    loongarch_lasx_xvssrani_hu_w,              // llvm.loongarch.lasx.xvssrani.hu.w
    loongarch_lasx_xvssrani_w_d,               // llvm.loongarch.lasx.xvssrani.w.d
    loongarch_lasx_xvssrani_wu_d,              // llvm.loongarch.lasx.xvssrani.wu.d
    loongarch_lasx_xvssrarn_b_h,               // llvm.loongarch.lasx.xvssrarn.b.h
    loongarch_lasx_xvssrarn_bu_h,              // llvm.loongarch.lasx.xvssrarn.bu.h
    loongarch_lasx_xvssrarn_h_w,               // llvm.loongarch.lasx.xvssrarn.h.w
    loongarch_lasx_xvssrarn_hu_w,              // llvm.loongarch.lasx.xvssrarn.hu.w
    loongarch_lasx_xvssrarn_w_d,               // llvm.loongarch.lasx.xvssrarn.w.d
    loongarch_lasx_xvssrarn_wu_d,              // llvm.loongarch.lasx.xvssrarn.wu.d
    loongarch_lasx_xvssrarni_b_h,              // llvm.loongarch.lasx.xvssrarni.b.h
    loongarch_lasx_xvssrarni_bu_h,             // llvm.loongarch.lasx.xvssrarni.bu.h
    loongarch_lasx_xvssrarni_d_q,              // llvm.loongarch.lasx.xvssrarni.d.q
    loongarch_lasx_xvssrarni_du_q,             // llvm.loongarch.lasx.xvssrarni.du.q
    loongarch_lasx_xvssrarni_h_w,              // llvm.loongarch.lasx.xvssrarni.h.w
    loongarch_lasx_xvssrarni_hu_w,             // llvm.loongarch.lasx.xvssrarni.hu.w
    loongarch_lasx_xvssrarni_w_d,              // llvm.loongarch.lasx.xvssrarni.w.d
    loongarch_lasx_xvssrarni_wu_d,             // llvm.loongarch.lasx.xvssrarni.wu.d
    loongarch_lasx_xvssrln_b_h,                // llvm.loongarch.lasx.xvssrln.b.h
    loongarch_lasx_xvssrln_bu_h,               // llvm.loongarch.lasx.xvssrln.bu.h
    loongarch_lasx_xvssrln_h_w,                // llvm.loongarch.lasx.xvssrln.h.w
    loongarch_lasx_xvssrln_hu_w,               // llvm.loongarch.lasx.xvssrln.hu.w
    loongarch_lasx_xvssrln_w_d,                // llvm.loongarch.lasx.xvssrln.w.d
    loongarch_lasx_xvssrln_wu_d,               // llvm.loongarch.lasx.xvssrln.wu.d
    loongarch_lasx_xvssrlni_b_h,               // llvm.loongarch.lasx.xvssrlni.b.h
    loongarch_lasx_xvssrlni_bu_h,              // llvm.loongarch.lasx.xvssrlni.bu.h
    loongarch_lasx_xvssrlni_d_q,               // llvm.loongarch.lasx.xvssrlni.d.q
    loongarch_lasx_xvssrlni_du_q,              // llvm.loongarch.lasx.xvssrlni.du.q
    loongarch_lasx_xvssrlni_h_w,               // llvm.loongarch.lasx.xvssrlni.h.w
    loongarch_lasx_xvssrlni_hu_w,              // llvm.loongarch.lasx.xvssrlni.hu.w
    loongarch_lasx_xvssrlni_w_d,               // llvm.loongarch.lasx.xvssrlni.w.d
    loongarch_lasx_xvssrlni_wu_d,              // llvm.loongarch.lasx.xvssrlni.wu.d
    loongarch_lasx_xvssrlrn_b_h,               // llvm.loongarch.lasx.xvssrlrn.b.h
    loongarch_lasx_xvssrlrn_bu_h,              // llvm.loongarch.lasx.xvssrlrn.bu.h
    loongarch_lasx_xvssrlrn_h_w,               // llvm.loongarch.lasx.xvssrlrn.h.w
    loongarch_lasx_xvssrlrn_hu_w,              // llvm.loongarch.lasx.xvssrlrn.hu.w
    loongarch_lasx_xvssrlrn_w_d,               // llvm.loongarch.lasx.xvssrlrn.w.d
    loongarch_lasx_xvssrlrn_wu_d,              // llvm.loongarch.lasx.xvssrlrn.wu.d
    loongarch_lasx_xvssrlrni_b_h,              // llvm.loongarch.lasx.xvssrlrni.b.h
    loongarch_lasx_xvssrlrni_bu_h,             // llvm.loongarch.lasx.xvssrlrni.bu.h
    loongarch_lasx_xvssrlrni_d_q,              // llvm.loongarch.lasx.xvssrlrni.d.q
    loongarch_lasx_xvssrlrni_du_q,             // llvm.loongarch.lasx.xvssrlrni.du.q
    loongarch_lasx_xvssrlrni_h_w,              // llvm.loongarch.lasx.xvssrlrni.h.w
    loongarch_lasx_xvssrlrni_hu_w,             // llvm.loongarch.lasx.xvssrlrni.hu.w
    loongarch_lasx_xvssrlrni_w_d,              // llvm.loongarch.lasx.xvssrlrni.w.d
    loongarch_lasx_xvssrlrni_wu_d,             // llvm.loongarch.lasx.xvssrlrni.wu.d
    loongarch_lasx_xvssub_b,                   // llvm.loongarch.lasx.xvssub.b
    loongarch_lasx_xvssub_bu,                  // llvm.loongarch.lasx.xvssub.bu
    loongarch_lasx_xvssub_d,                   // llvm.loongarch.lasx.xvssub.d
    loongarch_lasx_xvssub_du,                  // llvm.loongarch.lasx.xvssub.du
    loongarch_lasx_xvssub_h,                   // llvm.loongarch.lasx.xvssub.h
    loongarch_lasx_xvssub_hu,                  // llvm.loongarch.lasx.xvssub.hu
    loongarch_lasx_xvssub_w,                   // llvm.loongarch.lasx.xvssub.w
    loongarch_lasx_xvssub_wu,                  // llvm.loongarch.lasx.xvssub.wu
    loongarch_lasx_xvst,                       // llvm.loongarch.lasx.xvst
    loongarch_lasx_xvstelm_b,                  // llvm.loongarch.lasx.xvstelm.b
    loongarch_lasx_xvstelm_d,                  // llvm.loongarch.lasx.xvstelm.d
    loongarch_lasx_xvstelm_h,                  // llvm.loongarch.lasx.xvstelm.h
    loongarch_lasx_xvstelm_w,                  // llvm.loongarch.lasx.xvstelm.w
    loongarch_lasx_xvstx,                      // llvm.loongarch.lasx.xvstx
    loongarch_lasx_xvsub_b,                    // llvm.loongarch.lasx.xvsub.b
    loongarch_lasx_xvsub_d,                    // llvm.loongarch.lasx.xvsub.d
    loongarch_lasx_xvsub_h,                    // llvm.loongarch.lasx.xvsub.h
    loongarch_lasx_xvsub_q,                    // llvm.loongarch.lasx.xvsub.q
    loongarch_lasx_xvsub_w,                    // llvm.loongarch.lasx.xvsub.w
    loongarch_lasx_xvsubi_bu,                  // llvm.loongarch.lasx.xvsubi.bu
    loongarch_lasx_xvsubi_du,                  // llvm.loongarch.lasx.xvsubi.du
    loongarch_lasx_xvsubi_hu,                  // llvm.loongarch.lasx.xvsubi.hu
    loongarch_lasx_xvsubi_wu,                  // llvm.loongarch.lasx.xvsubi.wu
    loongarch_lasx_xvsubwev_d_w,               // llvm.loongarch.lasx.xvsubwev.d.w
    loongarch_lasx_xvsubwev_d_wu,              // llvm.loongarch.lasx.xvsubwev.d.wu
    loongarch_lasx_xvsubwev_h_b,               // llvm.loongarch.lasx.xvsubwev.h.b
    loongarch_lasx_xvsubwev_h_bu,              // llvm.loongarch.lasx.xvsubwev.h.bu
    loongarch_lasx_xvsubwev_q_d,               // llvm.loongarch.lasx.xvsubwev.q.d
    loongarch_lasx_xvsubwev_q_du,              // llvm.loongarch.lasx.xvsubwev.q.du
    loongarch_lasx_xvsubwev_w_h,               // llvm.loongarch.lasx.xvsubwev.w.h
    loongarch_lasx_xvsubwev_w_hu,              // llvm.loongarch.lasx.xvsubwev.w.hu
    loongarch_lasx_xvsubwod_d_w,               // llvm.loongarch.lasx.xvsubwod.d.w
    loongarch_lasx_xvsubwod_d_wu,              // llvm.loongarch.lasx.xvsubwod.d.wu
    loongarch_lasx_xvsubwod_h_b,               // llvm.loongarch.lasx.xvsubwod.h.b
    loongarch_lasx_xvsubwod_h_bu,              // llvm.loongarch.lasx.xvsubwod.h.bu
    loongarch_lasx_xvsubwod_q_d,               // llvm.loongarch.lasx.xvsubwod.q.d
    loongarch_lasx_xvsubwod_q_du,              // llvm.loongarch.lasx.xvsubwod.q.du
    loongarch_lasx_xvsubwod_w_h,               // llvm.loongarch.lasx.xvsubwod.w.h
    loongarch_lasx_xvsubwod_w_hu,              // llvm.loongarch.lasx.xvsubwod.w.hu
    loongarch_lasx_xvxor_v,                    // llvm.loongarch.lasx.xvxor.v
    loongarch_lasx_xvxori_b,                   // llvm.loongarch.lasx.xvxori.b
    loongarch_lddir_d,                         // llvm.loongarch.lddir.d
    loongarch_ldpte_d,                         // llvm.loongarch.ldpte.d
    loongarch_lsx_bnz_b,                       // llvm.loongarch.lsx.bnz.b
    loongarch_lsx_bnz_d,                       // llvm.loongarch.lsx.bnz.d
    loongarch_lsx_bnz_h,                       // llvm.loongarch.lsx.bnz.h
    loongarch_lsx_bnz_v,                       // llvm.loongarch.lsx.bnz.v
    loongarch_lsx_bnz_w,                       // llvm.loongarch.lsx.bnz.w
    loongarch_lsx_bz_b,                        // llvm.loongarch.lsx.bz.b
    loongarch_lsx_bz_d,                        // llvm.loongarch.lsx.bz.d
    loongarch_lsx_bz_h,                        // llvm.loongarch.lsx.bz.h
    loongarch_lsx_bz_v,                        // llvm.loongarch.lsx.bz.v
    loongarch_lsx_bz_w,                        // llvm.loongarch.lsx.bz.w
    loongarch_lsx_vabsd_b,                     // llvm.loongarch.lsx.vabsd.b
    loongarch_lsx_vabsd_bu,                    // llvm.loongarch.lsx.vabsd.bu
    loongarch_lsx_vabsd_d,                     // llvm.loongarch.lsx.vabsd.d
    loongarch_lsx_vabsd_du,                    // llvm.loongarch.lsx.vabsd.du
    loongarch_lsx_vabsd_h,                     // llvm.loongarch.lsx.vabsd.h
    loongarch_lsx_vabsd_hu,                    // llvm.loongarch.lsx.vabsd.hu
    loongarch_lsx_vabsd_w,                     // llvm.loongarch.lsx.vabsd.w
    loongarch_lsx_vabsd_wu,                    // llvm.loongarch.lsx.vabsd.wu
    loongarch_lsx_vadd_b,                      // llvm.loongarch.lsx.vadd.b
    loongarch_lsx_vadd_d,                      // llvm.loongarch.lsx.vadd.d
    loongarch_lsx_vadd_h,                      // llvm.loongarch.lsx.vadd.h
    loongarch_lsx_vadd_q,                      // llvm.loongarch.lsx.vadd.q
    loongarch_lsx_vadd_w,                      // llvm.loongarch.lsx.vadd.w
    loongarch_lsx_vadda_b,                     // llvm.loongarch.lsx.vadda.b
    loongarch_lsx_vadda_d,                     // llvm.loongarch.lsx.vadda.d
    loongarch_lsx_vadda_h,                     // llvm.loongarch.lsx.vadda.h
    loongarch_lsx_vadda_w,                     // llvm.loongarch.lsx.vadda.w
    loongarch_lsx_vaddi_bu,                    // llvm.loongarch.lsx.vaddi.bu
    loongarch_lsx_vaddi_du,                    // llvm.loongarch.lsx.vaddi.du
    loongarch_lsx_vaddi_hu,                    // llvm.loongarch.lsx.vaddi.hu
    loongarch_lsx_vaddi_wu,                    // llvm.loongarch.lsx.vaddi.wu
    loongarch_lsx_vaddwev_d_w,                 // llvm.loongarch.lsx.vaddwev.d.w
    loongarch_lsx_vaddwev_d_wu,                // llvm.loongarch.lsx.vaddwev.d.wu
    loongarch_lsx_vaddwev_d_wu_w,              // llvm.loongarch.lsx.vaddwev.d.wu.w
    loongarch_lsx_vaddwev_h_b,                 // llvm.loongarch.lsx.vaddwev.h.b
    loongarch_lsx_vaddwev_h_bu,                // llvm.loongarch.lsx.vaddwev.h.bu
    loongarch_lsx_vaddwev_h_bu_b,              // llvm.loongarch.lsx.vaddwev.h.bu.b
    loongarch_lsx_vaddwev_q_d,                 // llvm.loongarch.lsx.vaddwev.q.d
    loongarch_lsx_vaddwev_q_du,                // llvm.loongarch.lsx.vaddwev.q.du
    loongarch_lsx_vaddwev_q_du_d,              // llvm.loongarch.lsx.vaddwev.q.du.d
    loongarch_lsx_vaddwev_w_h,                 // llvm.loongarch.lsx.vaddwev.w.h
    loongarch_lsx_vaddwev_w_hu,                // llvm.loongarch.lsx.vaddwev.w.hu
    loongarch_lsx_vaddwev_w_hu_h,              // llvm.loongarch.lsx.vaddwev.w.hu.h
    loongarch_lsx_vaddwod_d_w,                 // llvm.loongarch.lsx.vaddwod.d.w
    loongarch_lsx_vaddwod_d_wu,                // llvm.loongarch.lsx.vaddwod.d.wu
    loongarch_lsx_vaddwod_d_wu_w,              // llvm.loongarch.lsx.vaddwod.d.wu.w
    loongarch_lsx_vaddwod_h_b,                 // llvm.loongarch.lsx.vaddwod.h.b
    loongarch_lsx_vaddwod_h_bu,                // llvm.loongarch.lsx.vaddwod.h.bu
    loongarch_lsx_vaddwod_h_bu_b,              // llvm.loongarch.lsx.vaddwod.h.bu.b
    loongarch_lsx_vaddwod_q_d,                 // llvm.loongarch.lsx.vaddwod.q.d
    loongarch_lsx_vaddwod_q_du,                // llvm.loongarch.lsx.vaddwod.q.du
    loongarch_lsx_vaddwod_q_du_d,              // llvm.loongarch.lsx.vaddwod.q.du.d
    loongarch_lsx_vaddwod_w_h,                 // llvm.loongarch.lsx.vaddwod.w.h
    loongarch_lsx_vaddwod_w_hu,                // llvm.loongarch.lsx.vaddwod.w.hu
    loongarch_lsx_vaddwod_w_hu_h,              // llvm.loongarch.lsx.vaddwod.w.hu.h
    loongarch_lsx_vand_v,                      // llvm.loongarch.lsx.vand.v
    loongarch_lsx_vandi_b,                     // llvm.loongarch.lsx.vandi.b
    loongarch_lsx_vandn_v,                     // llvm.loongarch.lsx.vandn.v
    loongarch_lsx_vavg_b,                      // llvm.loongarch.lsx.vavg.b
    loongarch_lsx_vavg_bu,                     // llvm.loongarch.lsx.vavg.bu
    loongarch_lsx_vavg_d,                      // llvm.loongarch.lsx.vavg.d
    loongarch_lsx_vavg_du,                     // llvm.loongarch.lsx.vavg.du
    loongarch_lsx_vavg_h,                      // llvm.loongarch.lsx.vavg.h
    loongarch_lsx_vavg_hu,                     // llvm.loongarch.lsx.vavg.hu
    loongarch_lsx_vavg_w,                      // llvm.loongarch.lsx.vavg.w
    loongarch_lsx_vavg_wu,                     // llvm.loongarch.lsx.vavg.wu
    loongarch_lsx_vavgr_b,                     // llvm.loongarch.lsx.vavgr.b
    loongarch_lsx_vavgr_bu,                    // llvm.loongarch.lsx.vavgr.bu
    loongarch_lsx_vavgr_d,                     // llvm.loongarch.lsx.vavgr.d
    loongarch_lsx_vavgr_du,                    // llvm.loongarch.lsx.vavgr.du
    loongarch_lsx_vavgr_h,                     // llvm.loongarch.lsx.vavgr.h
    loongarch_lsx_vavgr_hu,                    // llvm.loongarch.lsx.vavgr.hu
    loongarch_lsx_vavgr_w,                     // llvm.loongarch.lsx.vavgr.w
    loongarch_lsx_vavgr_wu,                    // llvm.loongarch.lsx.vavgr.wu
    loongarch_lsx_vbitclr_b,                   // llvm.loongarch.lsx.vbitclr.b
    loongarch_lsx_vbitclr_d,                   // llvm.loongarch.lsx.vbitclr.d
    loongarch_lsx_vbitclr_h,                   // llvm.loongarch.lsx.vbitclr.h
    loongarch_lsx_vbitclr_w,                   // llvm.loongarch.lsx.vbitclr.w
    loongarch_lsx_vbitclri_b,                  // llvm.loongarch.lsx.vbitclri.b
    loongarch_lsx_vbitclri_d,                  // llvm.loongarch.lsx.vbitclri.d
    loongarch_lsx_vbitclri_h,                  // llvm.loongarch.lsx.vbitclri.h
    loongarch_lsx_vbitclri_w,                  // llvm.loongarch.lsx.vbitclri.w
    loongarch_lsx_vbitrev_b,                   // llvm.loongarch.lsx.vbitrev.b
    loongarch_lsx_vbitrev_d,                   // llvm.loongarch.lsx.vbitrev.d
    loongarch_lsx_vbitrev_h,                   // llvm.loongarch.lsx.vbitrev.h
    loongarch_lsx_vbitrev_w,                   // llvm.loongarch.lsx.vbitrev.w
    loongarch_lsx_vbitrevi_b,                  // llvm.loongarch.lsx.vbitrevi.b
    loongarch_lsx_vbitrevi_d,                  // llvm.loongarch.lsx.vbitrevi.d
    loongarch_lsx_vbitrevi_h,                  // llvm.loongarch.lsx.vbitrevi.h
    loongarch_lsx_vbitrevi_w,                  // llvm.loongarch.lsx.vbitrevi.w
    loongarch_lsx_vbitsel_v,                   // llvm.loongarch.lsx.vbitsel.v
    loongarch_lsx_vbitseli_b,                  // llvm.loongarch.lsx.vbitseli.b
    loongarch_lsx_vbitset_b,                   // llvm.loongarch.lsx.vbitset.b
    loongarch_lsx_vbitset_d,                   // llvm.loongarch.lsx.vbitset.d
    loongarch_lsx_vbitset_h,                   // llvm.loongarch.lsx.vbitset.h
    loongarch_lsx_vbitset_w,                   // llvm.loongarch.lsx.vbitset.w
    loongarch_lsx_vbitseti_b,                  // llvm.loongarch.lsx.vbitseti.b
    loongarch_lsx_vbitseti_d,                  // llvm.loongarch.lsx.vbitseti.d
    loongarch_lsx_vbitseti_h,                  // llvm.loongarch.lsx.vbitseti.h
    loongarch_lsx_vbitseti_w,                  // llvm.loongarch.lsx.vbitseti.w
    loongarch_lsx_vbsll_v,                     // llvm.loongarch.lsx.vbsll.v
    loongarch_lsx_vbsrl_v,                     // llvm.loongarch.lsx.vbsrl.v
    loongarch_lsx_vclo_b,                      // llvm.loongarch.lsx.vclo.b
    loongarch_lsx_vclo_d,                      // llvm.loongarch.lsx.vclo.d
    loongarch_lsx_vclo_h,                      // llvm.loongarch.lsx.vclo.h
    loongarch_lsx_vclo_w,                      // llvm.loongarch.lsx.vclo.w
    loongarch_lsx_vclz_b,                      // llvm.loongarch.lsx.vclz.b
    loongarch_lsx_vclz_d,                      // llvm.loongarch.lsx.vclz.d
    loongarch_lsx_vclz_h,                      // llvm.loongarch.lsx.vclz.h
    loongarch_lsx_vclz_w,                      // llvm.loongarch.lsx.vclz.w
    loongarch_lsx_vdiv_b,                      // llvm.loongarch.lsx.vdiv.b
    loongarch_lsx_vdiv_bu,                     // llvm.loongarch.lsx.vdiv.bu
    loongarch_lsx_vdiv_d,                      // llvm.loongarch.lsx.vdiv.d
    loongarch_lsx_vdiv_du,                     // llvm.loongarch.lsx.vdiv.du
    loongarch_lsx_vdiv_h,                      // llvm.loongarch.lsx.vdiv.h
    loongarch_lsx_vdiv_hu,                     // llvm.loongarch.lsx.vdiv.hu
    loongarch_lsx_vdiv_w,                      // llvm.loongarch.lsx.vdiv.w
    loongarch_lsx_vdiv_wu,                     // llvm.loongarch.lsx.vdiv.wu
    loongarch_lsx_vexth_d_w,                   // llvm.loongarch.lsx.vexth.d.w
    loongarch_lsx_vexth_du_wu,                 // llvm.loongarch.lsx.vexth.du.wu
    loongarch_lsx_vexth_h_b,                   // llvm.loongarch.lsx.vexth.h.b
    loongarch_lsx_vexth_hu_bu,                 // llvm.loongarch.lsx.vexth.hu.bu
    loongarch_lsx_vexth_q_d,                   // llvm.loongarch.lsx.vexth.q.d
    loongarch_lsx_vexth_qu_du,                 // llvm.loongarch.lsx.vexth.qu.du
    loongarch_lsx_vexth_w_h,                   // llvm.loongarch.lsx.vexth.w.h
    loongarch_lsx_vexth_wu_hu,                 // llvm.loongarch.lsx.vexth.wu.hu
    loongarch_lsx_vextl_q_d,                   // llvm.loongarch.lsx.vextl.q.d
    loongarch_lsx_vextl_qu_du,                 // llvm.loongarch.lsx.vextl.qu.du
    loongarch_lsx_vextrins_b,                  // llvm.loongarch.lsx.vextrins.b
    loongarch_lsx_vextrins_d,                  // llvm.loongarch.lsx.vextrins.d
    loongarch_lsx_vextrins_h,                  // llvm.loongarch.lsx.vextrins.h
    loongarch_lsx_vextrins_w,                  // llvm.loongarch.lsx.vextrins.w
    loongarch_lsx_vfadd_d,                     // llvm.loongarch.lsx.vfadd.d
    loongarch_lsx_vfadd_s,                     // llvm.loongarch.lsx.vfadd.s
    loongarch_lsx_vfclass_d,                   // llvm.loongarch.lsx.vfclass.d
    loongarch_lsx_vfclass_s,                   // llvm.loongarch.lsx.vfclass.s
    loongarch_lsx_vfcmp_caf_d,                 // llvm.loongarch.lsx.vfcmp.caf.d
    loongarch_lsx_vfcmp_caf_s,                 // llvm.loongarch.lsx.vfcmp.caf.s
    loongarch_lsx_vfcmp_ceq_d,                 // llvm.loongarch.lsx.vfcmp.ceq.d
    loongarch_lsx_vfcmp_ceq_s,                 // llvm.loongarch.lsx.vfcmp.ceq.s
    loongarch_lsx_vfcmp_cle_d,                 // llvm.loongarch.lsx.vfcmp.cle.d
    loongarch_lsx_vfcmp_cle_s,                 // llvm.loongarch.lsx.vfcmp.cle.s
    loongarch_lsx_vfcmp_clt_d,                 // llvm.loongarch.lsx.vfcmp.clt.d
    loongarch_lsx_vfcmp_clt_s,                 // llvm.loongarch.lsx.vfcmp.clt.s
    loongarch_lsx_vfcmp_cne_d,                 // llvm.loongarch.lsx.vfcmp.cne.d
    loongarch_lsx_vfcmp_cne_s,                 // llvm.loongarch.lsx.vfcmp.cne.s
    loongarch_lsx_vfcmp_cor_d,                 // llvm.loongarch.lsx.vfcmp.cor.d
    loongarch_lsx_vfcmp_cor_s,                 // llvm.loongarch.lsx.vfcmp.cor.s
    loongarch_lsx_vfcmp_cueq_d,                // llvm.loongarch.lsx.vfcmp.cueq.d
    loongarch_lsx_vfcmp_cueq_s,                // llvm.loongarch.lsx.vfcmp.cueq.s
    loongarch_lsx_vfcmp_cule_d,                // llvm.loongarch.lsx.vfcmp.cule.d
    loongarch_lsx_vfcmp_cule_s,                // llvm.loongarch.lsx.vfcmp.cule.s
    loongarch_lsx_vfcmp_cult_d,                // llvm.loongarch.lsx.vfcmp.cult.d
    loongarch_lsx_vfcmp_cult_s,                // llvm.loongarch.lsx.vfcmp.cult.s
    loongarch_lsx_vfcmp_cun_d,                 // llvm.loongarch.lsx.vfcmp.cun.d
    loongarch_lsx_vfcmp_cun_s,                 // llvm.loongarch.lsx.vfcmp.cun.s
    loongarch_lsx_vfcmp_cune_d,                // llvm.loongarch.lsx.vfcmp.cune.d
    loongarch_lsx_vfcmp_cune_s,                // llvm.loongarch.lsx.vfcmp.cune.s
    loongarch_lsx_vfcmp_saf_d,                 // llvm.loongarch.lsx.vfcmp.saf.d
    loongarch_lsx_vfcmp_saf_s,                 // llvm.loongarch.lsx.vfcmp.saf.s
    loongarch_lsx_vfcmp_seq_d,                 // llvm.loongarch.lsx.vfcmp.seq.d
    loongarch_lsx_vfcmp_seq_s,                 // llvm.loongarch.lsx.vfcmp.seq.s
    loongarch_lsx_vfcmp_sle_d,                 // llvm.loongarch.lsx.vfcmp.sle.d
    loongarch_lsx_vfcmp_sle_s,                 // llvm.loongarch.lsx.vfcmp.sle.s
    loongarch_lsx_vfcmp_slt_d,                 // llvm.loongarch.lsx.vfcmp.slt.d
    loongarch_lsx_vfcmp_slt_s,                 // llvm.loongarch.lsx.vfcmp.slt.s
    loongarch_lsx_vfcmp_sne_d,                 // llvm.loongarch.lsx.vfcmp.sne.d
    loongarch_lsx_vfcmp_sne_s,                 // llvm.loongarch.lsx.vfcmp.sne.s
    loongarch_lsx_vfcmp_sor_d,                 // llvm.loongarch.lsx.vfcmp.sor.d
    loongarch_lsx_vfcmp_sor_s,                 // llvm.loongarch.lsx.vfcmp.sor.s
    loongarch_lsx_vfcmp_sueq_d,                // llvm.loongarch.lsx.vfcmp.sueq.d
    loongarch_lsx_vfcmp_sueq_s,                // llvm.loongarch.lsx.vfcmp.sueq.s
    loongarch_lsx_vfcmp_sule_d,                // llvm.loongarch.lsx.vfcmp.sule.d
    loongarch_lsx_vfcmp_sule_s,                // llvm.loongarch.lsx.vfcmp.sule.s
    loongarch_lsx_vfcmp_sult_d,                // llvm.loongarch.lsx.vfcmp.sult.d
    loongarch_lsx_vfcmp_sult_s,                // llvm.loongarch.lsx.vfcmp.sult.s
    loongarch_lsx_vfcmp_sun_d,                 // llvm.loongarch.lsx.vfcmp.sun.d
    loongarch_lsx_vfcmp_sun_s,                 // llvm.loongarch.lsx.vfcmp.sun.s
    loongarch_lsx_vfcmp_sune_d,                // llvm.loongarch.lsx.vfcmp.sune.d
    loongarch_lsx_vfcmp_sune_s,                // llvm.loongarch.lsx.vfcmp.sune.s
    loongarch_lsx_vfcvt_h_s,                   // llvm.loongarch.lsx.vfcvt.h.s
    loongarch_lsx_vfcvt_s_d,                   // llvm.loongarch.lsx.vfcvt.s.d
    loongarch_lsx_vfcvth_d_s,                  // llvm.loongarch.lsx.vfcvth.d.s
    loongarch_lsx_vfcvth_s_h,                  // llvm.loongarch.lsx.vfcvth.s.h
    loongarch_lsx_vfcvtl_d_s,                  // llvm.loongarch.lsx.vfcvtl.d.s
    loongarch_lsx_vfcvtl_s_h,                  // llvm.loongarch.lsx.vfcvtl.s.h
    loongarch_lsx_vfdiv_d,                     // llvm.loongarch.lsx.vfdiv.d
    loongarch_lsx_vfdiv_s,                     // llvm.loongarch.lsx.vfdiv.s
    loongarch_lsx_vffint_d_l,                  // llvm.loongarch.lsx.vffint.d.l
    loongarch_lsx_vffint_d_lu,                 // llvm.loongarch.lsx.vffint.d.lu
    loongarch_lsx_vffint_s_l,                  // llvm.loongarch.lsx.vffint.s.l
    loongarch_lsx_vffint_s_w,                  // llvm.loongarch.lsx.vffint.s.w
    loongarch_lsx_vffint_s_wu,                 // llvm.loongarch.lsx.vffint.s.wu
    loongarch_lsx_vffinth_d_w,                 // llvm.loongarch.lsx.vffinth.d.w
    loongarch_lsx_vffintl_d_w,                 // llvm.loongarch.lsx.vffintl.d.w
    loongarch_lsx_vflogb_d,                    // llvm.loongarch.lsx.vflogb.d
    loongarch_lsx_vflogb_s,                    // llvm.loongarch.lsx.vflogb.s
    loongarch_lsx_vfmadd_d,                    // llvm.loongarch.lsx.vfmadd.d
    loongarch_lsx_vfmadd_s,                    // llvm.loongarch.lsx.vfmadd.s
    loongarch_lsx_vfmax_d,                     // llvm.loongarch.lsx.vfmax.d
    loongarch_lsx_vfmax_s,                     // llvm.loongarch.lsx.vfmax.s
    loongarch_lsx_vfmaxa_d,                    // llvm.loongarch.lsx.vfmaxa.d
    loongarch_lsx_vfmaxa_s,                    // llvm.loongarch.lsx.vfmaxa.s
    loongarch_lsx_vfmin_d,                     // llvm.loongarch.lsx.vfmin.d
    loongarch_lsx_vfmin_s,                     // llvm.loongarch.lsx.vfmin.s
    loongarch_lsx_vfmina_d,                    // llvm.loongarch.lsx.vfmina.d
    loongarch_lsx_vfmina_s,                    // llvm.loongarch.lsx.vfmina.s
    loongarch_lsx_vfmsub_d,                    // llvm.loongarch.lsx.vfmsub.d
    loongarch_lsx_vfmsub_s,                    // llvm.loongarch.lsx.vfmsub.s
    loongarch_lsx_vfmul_d,                     // llvm.loongarch.lsx.vfmul.d
    loongarch_lsx_vfmul_s,                     // llvm.loongarch.lsx.vfmul.s
    loongarch_lsx_vfnmadd_d,                   // llvm.loongarch.lsx.vfnmadd.d
    loongarch_lsx_vfnmadd_s,                   // llvm.loongarch.lsx.vfnmadd.s
    loongarch_lsx_vfnmsub_d,                   // llvm.loongarch.lsx.vfnmsub.d
    loongarch_lsx_vfnmsub_s,                   // llvm.loongarch.lsx.vfnmsub.s
    loongarch_lsx_vfrecip_d,                   // llvm.loongarch.lsx.vfrecip.d
    loongarch_lsx_vfrecip_s,                   // llvm.loongarch.lsx.vfrecip.s
    loongarch_lsx_vfrecipe_d,                  // llvm.loongarch.lsx.vfrecipe.d
    loongarch_lsx_vfrecipe_s,                  // llvm.loongarch.lsx.vfrecipe.s
    loongarch_lsx_vfrint_d,                    // llvm.loongarch.lsx.vfrint.d
    loongarch_lsx_vfrint_s,                    // llvm.loongarch.lsx.vfrint.s
    loongarch_lsx_vfrintrm_d,                  // llvm.loongarch.lsx.vfrintrm.d
    loongarch_lsx_vfrintrm_s,                  // llvm.loongarch.lsx.vfrintrm.s
    loongarch_lsx_vfrintrne_d,                 // llvm.loongarch.lsx.vfrintrne.d
    loongarch_lsx_vfrintrne_s,                 // llvm.loongarch.lsx.vfrintrne.s
    loongarch_lsx_vfrintrp_d,                  // llvm.loongarch.lsx.vfrintrp.d
    loongarch_lsx_vfrintrp_s,                  // llvm.loongarch.lsx.vfrintrp.s
    loongarch_lsx_vfrintrz_d,                  // llvm.loongarch.lsx.vfrintrz.d
    loongarch_lsx_vfrintrz_s,                  // llvm.loongarch.lsx.vfrintrz.s
    loongarch_lsx_vfrsqrt_d,                   // llvm.loongarch.lsx.vfrsqrt.d
    loongarch_lsx_vfrsqrt_s,                   // llvm.loongarch.lsx.vfrsqrt.s
    loongarch_lsx_vfrsqrte_d,                  // llvm.loongarch.lsx.vfrsqrte.d
    loongarch_lsx_vfrsqrte_s,                  // llvm.loongarch.lsx.vfrsqrte.s
    loongarch_lsx_vfrstp_b,                    // llvm.loongarch.lsx.vfrstp.b
    loongarch_lsx_vfrstp_h,                    // llvm.loongarch.lsx.vfrstp.h
    loongarch_lsx_vfrstpi_b,                   // llvm.loongarch.lsx.vfrstpi.b
    loongarch_lsx_vfrstpi_h,                   // llvm.loongarch.lsx.vfrstpi.h
    loongarch_lsx_vfsqrt_d,                    // llvm.loongarch.lsx.vfsqrt.d
    loongarch_lsx_vfsqrt_s,                    // llvm.loongarch.lsx.vfsqrt.s
    loongarch_lsx_vfsub_d,                     // llvm.loongarch.lsx.vfsub.d
    loongarch_lsx_vfsub_s,                     // llvm.loongarch.lsx.vfsub.s
    loongarch_lsx_vftint_l_d,                  // llvm.loongarch.lsx.vftint.l.d
    loongarch_lsx_vftint_lu_d,                 // llvm.loongarch.lsx.vftint.lu.d
    loongarch_lsx_vftint_w_d,                  // llvm.loongarch.lsx.vftint.w.d
    loongarch_lsx_vftint_w_s,                  // llvm.loongarch.lsx.vftint.w.s
    loongarch_lsx_vftint_wu_s,                 // llvm.loongarch.lsx.vftint.wu.s
    loongarch_lsx_vftinth_l_s,                 // llvm.loongarch.lsx.vftinth.l.s
    loongarch_lsx_vftintl_l_s,                 // llvm.loongarch.lsx.vftintl.l.s
    loongarch_lsx_vftintrm_l_d,                // llvm.loongarch.lsx.vftintrm.l.d
    loongarch_lsx_vftintrm_w_d,                // llvm.loongarch.lsx.vftintrm.w.d
    loongarch_lsx_vftintrm_w_s,                // llvm.loongarch.lsx.vftintrm.w.s
    loongarch_lsx_vftintrmh_l_s,               // llvm.loongarch.lsx.vftintrmh.l.s
    loongarch_lsx_vftintrml_l_s,               // llvm.loongarch.lsx.vftintrml.l.s
    loongarch_lsx_vftintrne_l_d,               // llvm.loongarch.lsx.vftintrne.l.d
    loongarch_lsx_vftintrne_w_d,               // llvm.loongarch.lsx.vftintrne.w.d
    loongarch_lsx_vftintrne_w_s,               // llvm.loongarch.lsx.vftintrne.w.s
    loongarch_lsx_vftintrneh_l_s,              // llvm.loongarch.lsx.vftintrneh.l.s
    loongarch_lsx_vftintrnel_l_s,              // llvm.loongarch.lsx.vftintrnel.l.s
    loongarch_lsx_vftintrp_l_d,                // llvm.loongarch.lsx.vftintrp.l.d
    loongarch_lsx_vftintrp_w_d,                // llvm.loongarch.lsx.vftintrp.w.d
    loongarch_lsx_vftintrp_w_s,                // llvm.loongarch.lsx.vftintrp.w.s
    loongarch_lsx_vftintrph_l_s,               // llvm.loongarch.lsx.vftintrph.l.s
    loongarch_lsx_vftintrpl_l_s,               // llvm.loongarch.lsx.vftintrpl.l.s
    loongarch_lsx_vftintrz_l_d,                // llvm.loongarch.lsx.vftintrz.l.d
    loongarch_lsx_vftintrz_lu_d,               // llvm.loongarch.lsx.vftintrz.lu.d
    loongarch_lsx_vftintrz_w_d,                // llvm.loongarch.lsx.vftintrz.w.d
    loongarch_lsx_vftintrz_w_s,                // llvm.loongarch.lsx.vftintrz.w.s
    loongarch_lsx_vftintrz_wu_s,               // llvm.loongarch.lsx.vftintrz.wu.s
    loongarch_lsx_vftintrzh_l_s,               // llvm.loongarch.lsx.vftintrzh.l.s
    loongarch_lsx_vftintrzl_l_s,               // llvm.loongarch.lsx.vftintrzl.l.s
    loongarch_lsx_vhaddw_d_w,                  // llvm.loongarch.lsx.vhaddw.d.w
    loongarch_lsx_vhaddw_du_wu,                // llvm.loongarch.lsx.vhaddw.du.wu
    loongarch_lsx_vhaddw_h_b,                  // llvm.loongarch.lsx.vhaddw.h.b
    loongarch_lsx_vhaddw_hu_bu,                // llvm.loongarch.lsx.vhaddw.hu.bu
    loongarch_lsx_vhaddw_q_d,                  // llvm.loongarch.lsx.vhaddw.q.d
    loongarch_lsx_vhaddw_qu_du,                // llvm.loongarch.lsx.vhaddw.qu.du
    loongarch_lsx_vhaddw_w_h,                  // llvm.loongarch.lsx.vhaddw.w.h
    loongarch_lsx_vhaddw_wu_hu,                // llvm.loongarch.lsx.vhaddw.wu.hu
    loongarch_lsx_vhsubw_d_w,                  // llvm.loongarch.lsx.vhsubw.d.w
    loongarch_lsx_vhsubw_du_wu,                // llvm.loongarch.lsx.vhsubw.du.wu
    loongarch_lsx_vhsubw_h_b,                  // llvm.loongarch.lsx.vhsubw.h.b
    loongarch_lsx_vhsubw_hu_bu,                // llvm.loongarch.lsx.vhsubw.hu.bu
    loongarch_lsx_vhsubw_q_d,                  // llvm.loongarch.lsx.vhsubw.q.d
    loongarch_lsx_vhsubw_qu_du,                // llvm.loongarch.lsx.vhsubw.qu.du
    loongarch_lsx_vhsubw_w_h,                  // llvm.loongarch.lsx.vhsubw.w.h
    loongarch_lsx_vhsubw_wu_hu,                // llvm.loongarch.lsx.vhsubw.wu.hu
    loongarch_lsx_vilvh_b,                     // llvm.loongarch.lsx.vilvh.b
    loongarch_lsx_vilvh_d,                     // llvm.loongarch.lsx.vilvh.d
    loongarch_lsx_vilvh_h,                     // llvm.loongarch.lsx.vilvh.h
    loongarch_lsx_vilvh_w,                     // llvm.loongarch.lsx.vilvh.w
    loongarch_lsx_vilvl_b,                     // llvm.loongarch.lsx.vilvl.b
    loongarch_lsx_vilvl_d,                     // llvm.loongarch.lsx.vilvl.d
    loongarch_lsx_vilvl_h,                     // llvm.loongarch.lsx.vilvl.h
    loongarch_lsx_vilvl_w,                     // llvm.loongarch.lsx.vilvl.w
    loongarch_lsx_vinsgr2vr_b,                 // llvm.loongarch.lsx.vinsgr2vr.b
    loongarch_lsx_vinsgr2vr_d,                 // llvm.loongarch.lsx.vinsgr2vr.d
    loongarch_lsx_vinsgr2vr_h,                 // llvm.loongarch.lsx.vinsgr2vr.h
    loongarch_lsx_vinsgr2vr_w,                 // llvm.loongarch.lsx.vinsgr2vr.w
    loongarch_lsx_vld,                         // llvm.loongarch.lsx.vld
    loongarch_lsx_vldi,                        // llvm.loongarch.lsx.vldi
    loongarch_lsx_vldrepl_b,                   // llvm.loongarch.lsx.vldrepl.b
    loongarch_lsx_vldrepl_d,                   // llvm.loongarch.lsx.vldrepl.d
    loongarch_lsx_vldrepl_h,                   // llvm.loongarch.lsx.vldrepl.h
    loongarch_lsx_vldrepl_w,                   // llvm.loongarch.lsx.vldrepl.w
    loongarch_lsx_vldx,                        // llvm.loongarch.lsx.vldx
    loongarch_lsx_vmadd_b,                     // llvm.loongarch.lsx.vmadd.b
    loongarch_lsx_vmadd_d,                     // llvm.loongarch.lsx.vmadd.d
    loongarch_lsx_vmadd_h,                     // llvm.loongarch.lsx.vmadd.h
    loongarch_lsx_vmadd_w,                     // llvm.loongarch.lsx.vmadd.w
    loongarch_lsx_vmaddwev_d_w,                // llvm.loongarch.lsx.vmaddwev.d.w
    loongarch_lsx_vmaddwev_d_wu,               // llvm.loongarch.lsx.vmaddwev.d.wu
    loongarch_lsx_vmaddwev_d_wu_w,             // llvm.loongarch.lsx.vmaddwev.d.wu.w
    loongarch_lsx_vmaddwev_h_b,                // llvm.loongarch.lsx.vmaddwev.h.b
    loongarch_lsx_vmaddwev_h_bu,               // llvm.loongarch.lsx.vmaddwev.h.bu
    loongarch_lsx_vmaddwev_h_bu_b,             // llvm.loongarch.lsx.vmaddwev.h.bu.b
    loongarch_lsx_vmaddwev_q_d,                // llvm.loongarch.lsx.vmaddwev.q.d
    loongarch_lsx_vmaddwev_q_du,               // llvm.loongarch.lsx.vmaddwev.q.du
    loongarch_lsx_vmaddwev_q_du_d,             // llvm.loongarch.lsx.vmaddwev.q.du.d
    loongarch_lsx_vmaddwev_w_h,                // llvm.loongarch.lsx.vmaddwev.w.h
    loongarch_lsx_vmaddwev_w_hu,               // llvm.loongarch.lsx.vmaddwev.w.hu
    loongarch_lsx_vmaddwev_w_hu_h,             // llvm.loongarch.lsx.vmaddwev.w.hu.h
    loongarch_lsx_vmaddwod_d_w,                // llvm.loongarch.lsx.vmaddwod.d.w
    loongarch_lsx_vmaddwod_d_wu,               // llvm.loongarch.lsx.vmaddwod.d.wu
    loongarch_lsx_vmaddwod_d_wu_w,             // llvm.loongarch.lsx.vmaddwod.d.wu.w
    loongarch_lsx_vmaddwod_h_b,                // llvm.loongarch.lsx.vmaddwod.h.b
    loongarch_lsx_vmaddwod_h_bu,               // llvm.loongarch.lsx.vmaddwod.h.bu
    loongarch_lsx_vmaddwod_h_bu_b,             // llvm.loongarch.lsx.vmaddwod.h.bu.b
    loongarch_lsx_vmaddwod_q_d,                // llvm.loongarch.lsx.vmaddwod.q.d
    loongarch_lsx_vmaddwod_q_du,               // llvm.loongarch.lsx.vmaddwod.q.du
    loongarch_lsx_vmaddwod_q_du_d,             // llvm.loongarch.lsx.vmaddwod.q.du.d
    loongarch_lsx_vmaddwod_w_h,                // llvm.loongarch.lsx.vmaddwod.w.h
    loongarch_lsx_vmaddwod_w_hu,               // llvm.loongarch.lsx.vmaddwod.w.hu
    loongarch_lsx_vmaddwod_w_hu_h,             // llvm.loongarch.lsx.vmaddwod.w.hu.h
    loongarch_lsx_vmax_b,                      // llvm.loongarch.lsx.vmax.b
    loongarch_lsx_vmax_bu,                     // llvm.loongarch.lsx.vmax.bu
    loongarch_lsx_vmax_d,                      // llvm.loongarch.lsx.vmax.d
    loongarch_lsx_vmax_du,                     // llvm.loongarch.lsx.vmax.du
    loongarch_lsx_vmax_h,                      // llvm.loongarch.lsx.vmax.h
    loongarch_lsx_vmax_hu,                     // llvm.loongarch.lsx.vmax.hu
    loongarch_lsx_vmax_w,                      // llvm.loongarch.lsx.vmax.w
    loongarch_lsx_vmax_wu,                     // llvm.loongarch.lsx.vmax.wu
    loongarch_lsx_vmaxi_b,                     // llvm.loongarch.lsx.vmaxi.b
    loongarch_lsx_vmaxi_bu,                    // llvm.loongarch.lsx.vmaxi.bu
    loongarch_lsx_vmaxi_d,                     // llvm.loongarch.lsx.vmaxi.d
    loongarch_lsx_vmaxi_du,                    // llvm.loongarch.lsx.vmaxi.du
    loongarch_lsx_vmaxi_h,                     // llvm.loongarch.lsx.vmaxi.h
    loongarch_lsx_vmaxi_hu,                    // llvm.loongarch.lsx.vmaxi.hu
    loongarch_lsx_vmaxi_w,                     // llvm.loongarch.lsx.vmaxi.w
    loongarch_lsx_vmaxi_wu,                    // llvm.loongarch.lsx.vmaxi.wu
    loongarch_lsx_vmin_b,                      // llvm.loongarch.lsx.vmin.b
    loongarch_lsx_vmin_bu,                     // llvm.loongarch.lsx.vmin.bu
    loongarch_lsx_vmin_d,                      // llvm.loongarch.lsx.vmin.d
    loongarch_lsx_vmin_du,                     // llvm.loongarch.lsx.vmin.du
    loongarch_lsx_vmin_h,                      // llvm.loongarch.lsx.vmin.h
    loongarch_lsx_vmin_hu,                     // llvm.loongarch.lsx.vmin.hu
    loongarch_lsx_vmin_w,                      // llvm.loongarch.lsx.vmin.w
    loongarch_lsx_vmin_wu,                     // llvm.loongarch.lsx.vmin.wu
    loongarch_lsx_vmini_b,                     // llvm.loongarch.lsx.vmini.b
    loongarch_lsx_vmini_bu,                    // llvm.loongarch.lsx.vmini.bu
    loongarch_lsx_vmini_d,                     // llvm.loongarch.lsx.vmini.d
    loongarch_lsx_vmini_du,                    // llvm.loongarch.lsx.vmini.du
    loongarch_lsx_vmini_h,                     // llvm.loongarch.lsx.vmini.h
    loongarch_lsx_vmini_hu,                    // llvm.loongarch.lsx.vmini.hu
    loongarch_lsx_vmini_w,                     // llvm.loongarch.lsx.vmini.w
    loongarch_lsx_vmini_wu,                    // llvm.loongarch.lsx.vmini.wu
    loongarch_lsx_vmod_b,                      // llvm.loongarch.lsx.vmod.b
    loongarch_lsx_vmod_bu,                     // llvm.loongarch.lsx.vmod.bu
    loongarch_lsx_vmod_d,                      // llvm.loongarch.lsx.vmod.d
    loongarch_lsx_vmod_du,                     // llvm.loongarch.lsx.vmod.du
    loongarch_lsx_vmod_h,                      // llvm.loongarch.lsx.vmod.h
    loongarch_lsx_vmod_hu,                     // llvm.loongarch.lsx.vmod.hu
    loongarch_lsx_vmod_w,                      // llvm.loongarch.lsx.vmod.w
    loongarch_lsx_vmod_wu,                     // llvm.loongarch.lsx.vmod.wu
    loongarch_lsx_vmskgez_b,                   // llvm.loongarch.lsx.vmskgez.b
    loongarch_lsx_vmskltz_b,                   // llvm.loongarch.lsx.vmskltz.b
    loongarch_lsx_vmskltz_d,                   // llvm.loongarch.lsx.vmskltz.d
    loongarch_lsx_vmskltz_h,                   // llvm.loongarch.lsx.vmskltz.h
    loongarch_lsx_vmskltz_w,                   // llvm.loongarch.lsx.vmskltz.w
    loongarch_lsx_vmsknz_b,                    // llvm.loongarch.lsx.vmsknz.b
    loongarch_lsx_vmsub_b,                     // llvm.loongarch.lsx.vmsub.b
    loongarch_lsx_vmsub_d,                     // llvm.loongarch.lsx.vmsub.d
    loongarch_lsx_vmsub_h,                     // llvm.loongarch.lsx.vmsub.h
    loongarch_lsx_vmsub_w,                     // llvm.loongarch.lsx.vmsub.w
    loongarch_lsx_vmuh_b,                      // llvm.loongarch.lsx.vmuh.b
    loongarch_lsx_vmuh_bu,                     // llvm.loongarch.lsx.vmuh.bu
    loongarch_lsx_vmuh_d,                      // llvm.loongarch.lsx.vmuh.d
    loongarch_lsx_vmuh_du,                     // llvm.loongarch.lsx.vmuh.du
    loongarch_lsx_vmuh_h,                      // llvm.loongarch.lsx.vmuh.h
    loongarch_lsx_vmuh_hu,                     // llvm.loongarch.lsx.vmuh.hu
    loongarch_lsx_vmuh_w,                      // llvm.loongarch.lsx.vmuh.w
    loongarch_lsx_vmuh_wu,                     // llvm.loongarch.lsx.vmuh.wu
    loongarch_lsx_vmul_b,                      // llvm.loongarch.lsx.vmul.b
    loongarch_lsx_vmul_d,                      // llvm.loongarch.lsx.vmul.d
    loongarch_lsx_vmul_h,                      // llvm.loongarch.lsx.vmul.h
    loongarch_lsx_vmul_w,                      // llvm.loongarch.lsx.vmul.w
    loongarch_lsx_vmulwev_d_w,                 // llvm.loongarch.lsx.vmulwev.d.w
    loongarch_lsx_vmulwev_d_wu,                // llvm.loongarch.lsx.vmulwev.d.wu
    loongarch_lsx_vmulwev_d_wu_w,              // llvm.loongarch.lsx.vmulwev.d.wu.w
    loongarch_lsx_vmulwev_h_b,                 // llvm.loongarch.lsx.vmulwev.h.b
    loongarch_lsx_vmulwev_h_bu,                // llvm.loongarch.lsx.vmulwev.h.bu
    loongarch_lsx_vmulwev_h_bu_b,              // llvm.loongarch.lsx.vmulwev.h.bu.b
    loongarch_lsx_vmulwev_q_d,                 // llvm.loongarch.lsx.vmulwev.q.d
    loongarch_lsx_vmulwev_q_du,                // llvm.loongarch.lsx.vmulwev.q.du
    loongarch_lsx_vmulwev_q_du_d,              // llvm.loongarch.lsx.vmulwev.q.du.d
    loongarch_lsx_vmulwev_w_h,                 // llvm.loongarch.lsx.vmulwev.w.h
    loongarch_lsx_vmulwev_w_hu,                // llvm.loongarch.lsx.vmulwev.w.hu
    loongarch_lsx_vmulwev_w_hu_h,              // llvm.loongarch.lsx.vmulwev.w.hu.h
    loongarch_lsx_vmulwod_d_w,                 // llvm.loongarch.lsx.vmulwod.d.w
    loongarch_lsx_vmulwod_d_wu,                // llvm.loongarch.lsx.vmulwod.d.wu
    loongarch_lsx_vmulwod_d_wu_w,              // llvm.loongarch.lsx.vmulwod.d.wu.w
    loongarch_lsx_vmulwod_h_b,                 // llvm.loongarch.lsx.vmulwod.h.b
    loongarch_lsx_vmulwod_h_bu,                // llvm.loongarch.lsx.vmulwod.h.bu
    loongarch_lsx_vmulwod_h_bu_b,              // llvm.loongarch.lsx.vmulwod.h.bu.b
    loongarch_lsx_vmulwod_q_d,                 // llvm.loongarch.lsx.vmulwod.q.d
    loongarch_lsx_vmulwod_q_du,                // llvm.loongarch.lsx.vmulwod.q.du
    loongarch_lsx_vmulwod_q_du_d,              // llvm.loongarch.lsx.vmulwod.q.du.d
    loongarch_lsx_vmulwod_w_h,                 // llvm.loongarch.lsx.vmulwod.w.h
    loongarch_lsx_vmulwod_w_hu,                // llvm.loongarch.lsx.vmulwod.w.hu
    loongarch_lsx_vmulwod_w_hu_h,              // llvm.loongarch.lsx.vmulwod.w.hu.h
    loongarch_lsx_vneg_b,                      // llvm.loongarch.lsx.vneg.b
    loongarch_lsx_vneg_d,                      // llvm.loongarch.lsx.vneg.d
    loongarch_lsx_vneg_h,                      // llvm.loongarch.lsx.vneg.h
    loongarch_lsx_vneg_w,                      // llvm.loongarch.lsx.vneg.w
    loongarch_lsx_vnor_v,                      // llvm.loongarch.lsx.vnor.v
    loongarch_lsx_vnori_b,                     // llvm.loongarch.lsx.vnori.b
    loongarch_lsx_vor_v,                       // llvm.loongarch.lsx.vor.v
    loongarch_lsx_vori_b,                      // llvm.loongarch.lsx.vori.b
    loongarch_lsx_vorn_v,                      // llvm.loongarch.lsx.vorn.v
    loongarch_lsx_vpackev_b,                   // llvm.loongarch.lsx.vpackev.b
    loongarch_lsx_vpackev_d,                   // llvm.loongarch.lsx.vpackev.d
    loongarch_lsx_vpackev_h,                   // llvm.loongarch.lsx.vpackev.h
    loongarch_lsx_vpackev_w,                   // llvm.loongarch.lsx.vpackev.w
    loongarch_lsx_vpackod_b,                   // llvm.loongarch.lsx.vpackod.b
    loongarch_lsx_vpackod_d,                   // llvm.loongarch.lsx.vpackod.d
    loongarch_lsx_vpackod_h,                   // llvm.loongarch.lsx.vpackod.h
    loongarch_lsx_vpackod_w,                   // llvm.loongarch.lsx.vpackod.w
    loongarch_lsx_vpcnt_b,                     // llvm.loongarch.lsx.vpcnt.b
    loongarch_lsx_vpcnt_d,                     // llvm.loongarch.lsx.vpcnt.d
    loongarch_lsx_vpcnt_h,                     // llvm.loongarch.lsx.vpcnt.h
    loongarch_lsx_vpcnt_w,                     // llvm.loongarch.lsx.vpcnt.w
    loongarch_lsx_vpermi_w,                    // llvm.loongarch.lsx.vpermi.w
    loongarch_lsx_vpickev_b,                   // llvm.loongarch.lsx.vpickev.b
    loongarch_lsx_vpickev_d,                   // llvm.loongarch.lsx.vpickev.d
    loongarch_lsx_vpickev_h,                   // llvm.loongarch.lsx.vpickev.h
    loongarch_lsx_vpickev_w,                   // llvm.loongarch.lsx.vpickev.w
    loongarch_lsx_vpickod_b,                   // llvm.loongarch.lsx.vpickod.b
    loongarch_lsx_vpickod_d,                   // llvm.loongarch.lsx.vpickod.d
    loongarch_lsx_vpickod_h,                   // llvm.loongarch.lsx.vpickod.h
    loongarch_lsx_vpickod_w,                   // llvm.loongarch.lsx.vpickod.w
    loongarch_lsx_vpickve2gr_b,                // llvm.loongarch.lsx.vpickve2gr.b
    loongarch_lsx_vpickve2gr_bu,               // llvm.loongarch.lsx.vpickve2gr.bu
    loongarch_lsx_vpickve2gr_d,                // llvm.loongarch.lsx.vpickve2gr.d
    loongarch_lsx_vpickve2gr_du,               // llvm.loongarch.lsx.vpickve2gr.du
    loongarch_lsx_vpickve2gr_h,                // llvm.loongarch.lsx.vpickve2gr.h
    loongarch_lsx_vpickve2gr_hu,               // llvm.loongarch.lsx.vpickve2gr.hu
    loongarch_lsx_vpickve2gr_w,                // llvm.loongarch.lsx.vpickve2gr.w
    loongarch_lsx_vpickve2gr_wu,               // llvm.loongarch.lsx.vpickve2gr.wu
    loongarch_lsx_vreplgr2vr_b,                // llvm.loongarch.lsx.vreplgr2vr.b
    loongarch_lsx_vreplgr2vr_d,                // llvm.loongarch.lsx.vreplgr2vr.d
    loongarch_lsx_vreplgr2vr_h,                // llvm.loongarch.lsx.vreplgr2vr.h
    loongarch_lsx_vreplgr2vr_w,                // llvm.loongarch.lsx.vreplgr2vr.w
    loongarch_lsx_vrepli_b,                    // llvm.loongarch.lsx.vrepli.b
    loongarch_lsx_vrepli_d,                    // llvm.loongarch.lsx.vrepli.d
    loongarch_lsx_vrepli_h,                    // llvm.loongarch.lsx.vrepli.h
    loongarch_lsx_vrepli_w,                    // llvm.loongarch.lsx.vrepli.w
    loongarch_lsx_vreplve_b,                   // llvm.loongarch.lsx.vreplve.b
    loongarch_lsx_vreplve_d,                   // llvm.loongarch.lsx.vreplve.d
    loongarch_lsx_vreplve_h,                   // llvm.loongarch.lsx.vreplve.h
    loongarch_lsx_vreplve_w,                   // llvm.loongarch.lsx.vreplve.w
    loongarch_lsx_vreplvei_b,                  // llvm.loongarch.lsx.vreplvei.b
    loongarch_lsx_vreplvei_d,                  // llvm.loongarch.lsx.vreplvei.d
    loongarch_lsx_vreplvei_h,                  // llvm.loongarch.lsx.vreplvei.h
    loongarch_lsx_vreplvei_w,                  // llvm.loongarch.lsx.vreplvei.w
    loongarch_lsx_vrotr_b,                     // llvm.loongarch.lsx.vrotr.b
    loongarch_lsx_vrotr_d,                     // llvm.loongarch.lsx.vrotr.d
    loongarch_lsx_vrotr_h,                     // llvm.loongarch.lsx.vrotr.h
    loongarch_lsx_vrotr_w,                     // llvm.loongarch.lsx.vrotr.w
    loongarch_lsx_vrotri_b,                    // llvm.loongarch.lsx.vrotri.b
    loongarch_lsx_vrotri_d,                    // llvm.loongarch.lsx.vrotri.d
    loongarch_lsx_vrotri_h,                    // llvm.loongarch.lsx.vrotri.h
    loongarch_lsx_vrotri_w,                    // llvm.loongarch.lsx.vrotri.w
    loongarch_lsx_vsadd_b,                     // llvm.loongarch.lsx.vsadd.b
    loongarch_lsx_vsadd_bu,                    // llvm.loongarch.lsx.vsadd.bu
    loongarch_lsx_vsadd_d,                     // llvm.loongarch.lsx.vsadd.d
    loongarch_lsx_vsadd_du,                    // llvm.loongarch.lsx.vsadd.du
    loongarch_lsx_vsadd_h,                     // llvm.loongarch.lsx.vsadd.h
    loongarch_lsx_vsadd_hu,                    // llvm.loongarch.lsx.vsadd.hu
    loongarch_lsx_vsadd_w,                     // llvm.loongarch.lsx.vsadd.w
    loongarch_lsx_vsadd_wu,                    // llvm.loongarch.lsx.vsadd.wu
    loongarch_lsx_vsat_b,                      // llvm.loongarch.lsx.vsat.b
    loongarch_lsx_vsat_bu,                     // llvm.loongarch.lsx.vsat.bu
    loongarch_lsx_vsat_d,                      // llvm.loongarch.lsx.vsat.d
    loongarch_lsx_vsat_du,                     // llvm.loongarch.lsx.vsat.du
    loongarch_lsx_vsat_h,                      // llvm.loongarch.lsx.vsat.h
    loongarch_lsx_vsat_hu,                     // llvm.loongarch.lsx.vsat.hu
    loongarch_lsx_vsat_w,                      // llvm.loongarch.lsx.vsat.w
    loongarch_lsx_vsat_wu,                     // llvm.loongarch.lsx.vsat.wu
    loongarch_lsx_vseq_b,                      // llvm.loongarch.lsx.vseq.b
    loongarch_lsx_vseq_d,                      // llvm.loongarch.lsx.vseq.d
    loongarch_lsx_vseq_h,                      // llvm.loongarch.lsx.vseq.h
    loongarch_lsx_vseq_w,                      // llvm.loongarch.lsx.vseq.w
    loongarch_lsx_vseqi_b,                     // llvm.loongarch.lsx.vseqi.b
    loongarch_lsx_vseqi_d,                     // llvm.loongarch.lsx.vseqi.d
    loongarch_lsx_vseqi_h,                     // llvm.loongarch.lsx.vseqi.h
    loongarch_lsx_vseqi_w,                     // llvm.loongarch.lsx.vseqi.w
    loongarch_lsx_vshuf_b,                     // llvm.loongarch.lsx.vshuf.b
    loongarch_lsx_vshuf_d,                     // llvm.loongarch.lsx.vshuf.d
    loongarch_lsx_vshuf_h,                     // llvm.loongarch.lsx.vshuf.h
    loongarch_lsx_vshuf_w,                     // llvm.loongarch.lsx.vshuf.w
    loongarch_lsx_vshuf4i_b,                   // llvm.loongarch.lsx.vshuf4i.b
    loongarch_lsx_vshuf4i_d,                   // llvm.loongarch.lsx.vshuf4i.d
    loongarch_lsx_vshuf4i_h,                   // llvm.loongarch.lsx.vshuf4i.h
    loongarch_lsx_vshuf4i_w,                   // llvm.loongarch.lsx.vshuf4i.w
    loongarch_lsx_vsigncov_b,                  // llvm.loongarch.lsx.vsigncov.b
    loongarch_lsx_vsigncov_d,                  // llvm.loongarch.lsx.vsigncov.d
    loongarch_lsx_vsigncov_h,                  // llvm.loongarch.lsx.vsigncov.h
    loongarch_lsx_vsigncov_w,                  // llvm.loongarch.lsx.vsigncov.w
    loongarch_lsx_vsle_b,                      // llvm.loongarch.lsx.vsle.b
    loongarch_lsx_vsle_bu,                     // llvm.loongarch.lsx.vsle.bu
    loongarch_lsx_vsle_d,                      // llvm.loongarch.lsx.vsle.d
    loongarch_lsx_vsle_du,                     // llvm.loongarch.lsx.vsle.du
    loongarch_lsx_vsle_h,                      // llvm.loongarch.lsx.vsle.h
    loongarch_lsx_vsle_hu,                     // llvm.loongarch.lsx.vsle.hu
    loongarch_lsx_vsle_w,                      // llvm.loongarch.lsx.vsle.w
    loongarch_lsx_vsle_wu,                     // llvm.loongarch.lsx.vsle.wu
    loongarch_lsx_vslei_b,                     // llvm.loongarch.lsx.vslei.b
    loongarch_lsx_vslei_bu,                    // llvm.loongarch.lsx.vslei.bu
    loongarch_lsx_vslei_d,                     // llvm.loongarch.lsx.vslei.d
    loongarch_lsx_vslei_du,                    // llvm.loongarch.lsx.vslei.du
    loongarch_lsx_vslei_h,                     // llvm.loongarch.lsx.vslei.h
    loongarch_lsx_vslei_hu,                    // llvm.loongarch.lsx.vslei.hu
    loongarch_lsx_vslei_w,                     // llvm.loongarch.lsx.vslei.w
    loongarch_lsx_vslei_wu,                    // llvm.loongarch.lsx.vslei.wu
    loongarch_lsx_vsll_b,                      // llvm.loongarch.lsx.vsll.b
    loongarch_lsx_vsll_d,                      // llvm.loongarch.lsx.vsll.d
    loongarch_lsx_vsll_h,                      // llvm.loongarch.lsx.vsll.h
    loongarch_lsx_vsll_w,                      // llvm.loongarch.lsx.vsll.w
    loongarch_lsx_vslli_b,                     // llvm.loongarch.lsx.vslli.b
    loongarch_lsx_vslli_d,                     // llvm.loongarch.lsx.vslli.d
    loongarch_lsx_vslli_h,                     // llvm.loongarch.lsx.vslli.h
    loongarch_lsx_vslli_w,                     // llvm.loongarch.lsx.vslli.w
    loongarch_lsx_vsllwil_d_w,                 // llvm.loongarch.lsx.vsllwil.d.w
    loongarch_lsx_vsllwil_du_wu,               // llvm.loongarch.lsx.vsllwil.du.wu
    loongarch_lsx_vsllwil_h_b,                 // llvm.loongarch.lsx.vsllwil.h.b
    loongarch_lsx_vsllwil_hu_bu,               // llvm.loongarch.lsx.vsllwil.hu.bu
    loongarch_lsx_vsllwil_w_h,                 // llvm.loongarch.lsx.vsllwil.w.h
    loongarch_lsx_vsllwil_wu_hu,               // llvm.loongarch.lsx.vsllwil.wu.hu
    loongarch_lsx_vslt_b,                      // llvm.loongarch.lsx.vslt.b
    loongarch_lsx_vslt_bu,                     // llvm.loongarch.lsx.vslt.bu
    loongarch_lsx_vslt_d,                      // llvm.loongarch.lsx.vslt.d
    loongarch_lsx_vslt_du,                     // llvm.loongarch.lsx.vslt.du
    loongarch_lsx_vslt_h,                      // llvm.loongarch.lsx.vslt.h
    loongarch_lsx_vslt_hu,                     // llvm.loongarch.lsx.vslt.hu
    loongarch_lsx_vslt_w,                      // llvm.loongarch.lsx.vslt.w
    loongarch_lsx_vslt_wu,                     // llvm.loongarch.lsx.vslt.wu
    loongarch_lsx_vslti_b,                     // llvm.loongarch.lsx.vslti.b
    loongarch_lsx_vslti_bu,                    // llvm.loongarch.lsx.vslti.bu
    loongarch_lsx_vslti_d,                     // llvm.loongarch.lsx.vslti.d
    loongarch_lsx_vslti_du,                    // llvm.loongarch.lsx.vslti.du
    loongarch_lsx_vslti_h,                     // llvm.loongarch.lsx.vslti.h
    loongarch_lsx_vslti_hu,                    // llvm.loongarch.lsx.vslti.hu
    loongarch_lsx_vslti_w,                     // llvm.loongarch.lsx.vslti.w
    loongarch_lsx_vslti_wu,                    // llvm.loongarch.lsx.vslti.wu
    loongarch_lsx_vsra_b,                      // llvm.loongarch.lsx.vsra.b
    loongarch_lsx_vsra_d,                      // llvm.loongarch.lsx.vsra.d
    loongarch_lsx_vsra_h,                      // llvm.loongarch.lsx.vsra.h
    loongarch_lsx_vsra_w,                      // llvm.loongarch.lsx.vsra.w
    loongarch_lsx_vsrai_b,                     // llvm.loongarch.lsx.vsrai.b
    loongarch_lsx_vsrai_d,                     // llvm.loongarch.lsx.vsrai.d
    loongarch_lsx_vsrai_h,                     // llvm.loongarch.lsx.vsrai.h
    loongarch_lsx_vsrai_w,                     // llvm.loongarch.lsx.vsrai.w
    loongarch_lsx_vsran_b_h,                   // llvm.loongarch.lsx.vsran.b.h
    loongarch_lsx_vsran_h_w,                   // llvm.loongarch.lsx.vsran.h.w
    loongarch_lsx_vsran_w_d,                   // llvm.loongarch.lsx.vsran.w.d
    loongarch_lsx_vsrani_b_h,                  // llvm.loongarch.lsx.vsrani.b.h
    loongarch_lsx_vsrani_d_q,                  // llvm.loongarch.lsx.vsrani.d.q
    loongarch_lsx_vsrani_h_w,                  // llvm.loongarch.lsx.vsrani.h.w
    loongarch_lsx_vsrani_w_d,                  // llvm.loongarch.lsx.vsrani.w.d
    loongarch_lsx_vsrar_b,                     // llvm.loongarch.lsx.vsrar.b
    loongarch_lsx_vsrar_d,                     // llvm.loongarch.lsx.vsrar.d
    loongarch_lsx_vsrar_h,                     // llvm.loongarch.lsx.vsrar.h
    loongarch_lsx_vsrar_w,                     // llvm.loongarch.lsx.vsrar.w
    loongarch_lsx_vsrari_b,                    // llvm.loongarch.lsx.vsrari.b
    loongarch_lsx_vsrari_d,                    // llvm.loongarch.lsx.vsrari.d
    loongarch_lsx_vsrari_h,                    // llvm.loongarch.lsx.vsrari.h
    loongarch_lsx_vsrari_w,                    // llvm.loongarch.lsx.vsrari.w
    loongarch_lsx_vsrarn_b_h,                  // llvm.loongarch.lsx.vsrarn.b.h
    loongarch_lsx_vsrarn_h_w,                  // llvm.loongarch.lsx.vsrarn.h.w
    loongarch_lsx_vsrarn_w_d,                  // llvm.loongarch.lsx.vsrarn.w.d
    loongarch_lsx_vsrarni_b_h,                 // llvm.loongarch.lsx.vsrarni.b.h
    loongarch_lsx_vsrarni_d_q,                 // llvm.loongarch.lsx.vsrarni.d.q
    loongarch_lsx_vsrarni_h_w,                 // llvm.loongarch.lsx.vsrarni.h.w
    loongarch_lsx_vsrarni_w_d,                 // llvm.loongarch.lsx.vsrarni.w.d
    loongarch_lsx_vsrl_b,                      // llvm.loongarch.lsx.vsrl.b
    loongarch_lsx_vsrl_d,                      // llvm.loongarch.lsx.vsrl.d
    loongarch_lsx_vsrl_h,                      // llvm.loongarch.lsx.vsrl.h
    loongarch_lsx_vsrl_w,                      // llvm.loongarch.lsx.vsrl.w
    loongarch_lsx_vsrli_b,                     // llvm.loongarch.lsx.vsrli.b
    loongarch_lsx_vsrli_d,                     // llvm.loongarch.lsx.vsrli.d
    loongarch_lsx_vsrli_h,                     // llvm.loongarch.lsx.vsrli.h
    loongarch_lsx_vsrli_w,                     // llvm.loongarch.lsx.vsrli.w
    loongarch_lsx_vsrln_b_h,                   // llvm.loongarch.lsx.vsrln.b.h
    loongarch_lsx_vsrln_h_w,                   // llvm.loongarch.lsx.vsrln.h.w
    loongarch_lsx_vsrln_w_d,                   // llvm.loongarch.lsx.vsrln.w.d
    loongarch_lsx_vsrlni_b_h,                  // llvm.loongarch.lsx.vsrlni.b.h
    loongarch_lsx_vsrlni_d_q,                  // llvm.loongarch.lsx.vsrlni.d.q
    loongarch_lsx_vsrlni_h_w,                  // llvm.loongarch.lsx.vsrlni.h.w
    loongarch_lsx_vsrlni_w_d,                  // llvm.loongarch.lsx.vsrlni.w.d
    loongarch_lsx_vsrlr_b,                     // llvm.loongarch.lsx.vsrlr.b
    loongarch_lsx_vsrlr_d,                     // llvm.loongarch.lsx.vsrlr.d
    loongarch_lsx_vsrlr_h,                     // llvm.loongarch.lsx.vsrlr.h
    loongarch_lsx_vsrlr_w,                     // llvm.loongarch.lsx.vsrlr.w
    loongarch_lsx_vsrlri_b,                    // llvm.loongarch.lsx.vsrlri.b
    loongarch_lsx_vsrlri_d,                    // llvm.loongarch.lsx.vsrlri.d
    loongarch_lsx_vsrlri_h,                    // llvm.loongarch.lsx.vsrlri.h
    loongarch_lsx_vsrlri_w,                    // llvm.loongarch.lsx.vsrlri.w
    loongarch_lsx_vsrlrn_b_h,                  // llvm.loongarch.lsx.vsrlrn.b.h
    loongarch_lsx_vsrlrn_h_w,                  // llvm.loongarch.lsx.vsrlrn.h.w
    loongarch_lsx_vsrlrn_w_d,                  // llvm.loongarch.lsx.vsrlrn.w.d
    loongarch_lsx_vsrlrni_b_h,                 // llvm.loongarch.lsx.vsrlrni.b.h
    loongarch_lsx_vsrlrni_d_q,                 // llvm.loongarch.lsx.vsrlrni.d.q
    loongarch_lsx_vsrlrni_h_w,                 // llvm.loongarch.lsx.vsrlrni.h.w
    loongarch_lsx_vsrlrni_w_d,                 // llvm.loongarch.lsx.vsrlrni.w.d
    loongarch_lsx_vssran_b_h,                  // llvm.loongarch.lsx.vssran.b.h
    loongarch_lsx_vssran_bu_h,                 // llvm.loongarch.lsx.vssran.bu.h
    loongarch_lsx_vssran_h_w,                  // llvm.loongarch.lsx.vssran.h.w
    loongarch_lsx_vssran_hu_w,                 // llvm.loongarch.lsx.vssran.hu.w
    loongarch_lsx_vssran_w_d,                  // llvm.loongarch.lsx.vssran.w.d
    loongarch_lsx_vssran_wu_d,                 // llvm.loongarch.lsx.vssran.wu.d
    loongarch_lsx_vssrani_b_h,                 // llvm.loongarch.lsx.vssrani.b.h
    loongarch_lsx_vssrani_bu_h,                // llvm.loongarch.lsx.vssrani.bu.h
    loongarch_lsx_vssrani_d_q,                 // llvm.loongarch.lsx.vssrani.d.q
    loongarch_lsx_vssrani_du_q,                // llvm.loongarch.lsx.vssrani.du.q
    loongarch_lsx_vssrani_h_w,                 // llvm.loongarch.lsx.vssrani.h.w
    loongarch_lsx_vssrani_hu_w,                // llvm.loongarch.lsx.vssrani.hu.w
    loongarch_lsx_vssrani_w_d,                 // llvm.loongarch.lsx.vssrani.w.d
    loongarch_lsx_vssrani_wu_d,                // llvm.loongarch.lsx.vssrani.wu.d
    loongarch_lsx_vssrarn_b_h,                 // llvm.loongarch.lsx.vssrarn.b.h
    loongarch_lsx_vssrarn_bu_h,                // llvm.loongarch.lsx.vssrarn.bu.h
    loongarch_lsx_vssrarn_h_w,                 // llvm.loongarch.lsx.vssrarn.h.w
    loongarch_lsx_vssrarn_hu_w,                // llvm.loongarch.lsx.vssrarn.hu.w
    loongarch_lsx_vssrarn_w_d,                 // llvm.loongarch.lsx.vssrarn.w.d
    loongarch_lsx_vssrarn_wu_d,                // llvm.loongarch.lsx.vssrarn.wu.d
    loongarch_lsx_vssrarni_b_h,                // llvm.loongarch.lsx.vssrarni.b.h
    loongarch_lsx_vssrarni_bu_h,               // llvm.loongarch.lsx.vssrarni.bu.h
    loongarch_lsx_vssrarni_d_q,                // llvm.loongarch.lsx.vssrarni.d.q
    loongarch_lsx_vssrarni_du_q,               // llvm.loongarch.lsx.vssrarni.du.q
    loongarch_lsx_vssrarni_h_w,                // llvm.loongarch.lsx.vssrarni.h.w
    loongarch_lsx_vssrarni_hu_w,               // llvm.loongarch.lsx.vssrarni.hu.w
    loongarch_lsx_vssrarni_w_d,                // llvm.loongarch.lsx.vssrarni.w.d
    loongarch_lsx_vssrarni_wu_d,               // llvm.loongarch.lsx.vssrarni.wu.d
    loongarch_lsx_vssrln_b_h,                  // llvm.loongarch.lsx.vssrln.b.h
    loongarch_lsx_vssrln_bu_h,                 // llvm.loongarch.lsx.vssrln.bu.h
    loongarch_lsx_vssrln_h_w,                  // llvm.loongarch.lsx.vssrln.h.w
    loongarch_lsx_vssrln_hu_w,                 // llvm.loongarch.lsx.vssrln.hu.w
    loongarch_lsx_vssrln_w_d,                  // llvm.loongarch.lsx.vssrln.w.d
    loongarch_lsx_vssrln_wu_d,                 // llvm.loongarch.lsx.vssrln.wu.d
    loongarch_lsx_vssrlni_b_h,                 // llvm.loongarch.lsx.vssrlni.b.h
    loongarch_lsx_vssrlni_bu_h,                // llvm.loongarch.lsx.vssrlni.bu.h
    loongarch_lsx_vssrlni_d_q,                 // llvm.loongarch.lsx.vssrlni.d.q
    loongarch_lsx_vssrlni_du_q,                // llvm.loongarch.lsx.vssrlni.du.q
    loongarch_lsx_vssrlni_h_w,                 // llvm.loongarch.lsx.vssrlni.h.w
    loongarch_lsx_vssrlni_hu_w,                // llvm.loongarch.lsx.vssrlni.hu.w
    loongarch_lsx_vssrlni_w_d,                 // llvm.loongarch.lsx.vssrlni.w.d
    loongarch_lsx_vssrlni_wu_d,                // llvm.loongarch.lsx.vssrlni.wu.d
    loongarch_lsx_vssrlrn_b_h,                 // llvm.loongarch.lsx.vssrlrn.b.h
    loongarch_lsx_vssrlrn_bu_h,                // llvm.loongarch.lsx.vssrlrn.bu.h
    loongarch_lsx_vssrlrn_h_w,                 // llvm.loongarch.lsx.vssrlrn.h.w
    loongarch_lsx_vssrlrn_hu_w,                // llvm.loongarch.lsx.vssrlrn.hu.w
    loongarch_lsx_vssrlrn_w_d,                 // llvm.loongarch.lsx.vssrlrn.w.d
    loongarch_lsx_vssrlrn_wu_d,                // llvm.loongarch.lsx.vssrlrn.wu.d
    loongarch_lsx_vssrlrni_b_h,                // llvm.loongarch.lsx.vssrlrni.b.h
    loongarch_lsx_vssrlrni_bu_h,               // llvm.loongarch.lsx.vssrlrni.bu.h
    loongarch_lsx_vssrlrni_d_q,                // llvm.loongarch.lsx.vssrlrni.d.q
    loongarch_lsx_vssrlrni_du_q,               // llvm.loongarch.lsx.vssrlrni.du.q
    loongarch_lsx_vssrlrni_h_w,                // llvm.loongarch.lsx.vssrlrni.h.w
    loongarch_lsx_vssrlrni_hu_w,               // llvm.loongarch.lsx.vssrlrni.hu.w
    loongarch_lsx_vssrlrni_w_d,                // llvm.loongarch.lsx.vssrlrni.w.d
    loongarch_lsx_vssrlrni_wu_d,               // llvm.loongarch.lsx.vssrlrni.wu.d
    loongarch_lsx_vssub_b,                     // llvm.loongarch.lsx.vssub.b
    loongarch_lsx_vssub_bu,                    // llvm.loongarch.lsx.vssub.bu
    loongarch_lsx_vssub_d,                     // llvm.loongarch.lsx.vssub.d
    loongarch_lsx_vssub_du,                    // llvm.loongarch.lsx.vssub.du
    loongarch_lsx_vssub_h,                     // llvm.loongarch.lsx.vssub.h
    loongarch_lsx_vssub_hu,                    // llvm.loongarch.lsx.vssub.hu
    loongarch_lsx_vssub_w,                     // llvm.loongarch.lsx.vssub.w
    loongarch_lsx_vssub_wu,                    // llvm.loongarch.lsx.vssub.wu
    loongarch_lsx_vst,                         // llvm.loongarch.lsx.vst
    loongarch_lsx_vstelm_b,                    // llvm.loongarch.lsx.vstelm.b
    loongarch_lsx_vstelm_d,                    // llvm.loongarch.lsx.vstelm.d
    loongarch_lsx_vstelm_h,                    // llvm.loongarch.lsx.vstelm.h
    loongarch_lsx_vstelm_w,                    // llvm.loongarch.lsx.vstelm.w
    loongarch_lsx_vstx,                        // llvm.loongarch.lsx.vstx
    loongarch_lsx_vsub_b,                      // llvm.loongarch.lsx.vsub.b
    loongarch_lsx_vsub_d,                      // llvm.loongarch.lsx.vsub.d
    loongarch_lsx_vsub_h,                      // llvm.loongarch.lsx.vsub.h
    loongarch_lsx_vsub_q,                      // llvm.loongarch.lsx.vsub.q
    loongarch_lsx_vsub_w,                      // llvm.loongarch.lsx.vsub.w
    loongarch_lsx_vsubi_bu,                    // llvm.loongarch.lsx.vsubi.bu
    loongarch_lsx_vsubi_du,                    // llvm.loongarch.lsx.vsubi.du
    loongarch_lsx_vsubi_hu,                    // llvm.loongarch.lsx.vsubi.hu
    loongarch_lsx_vsubi_wu,                    // llvm.loongarch.lsx.vsubi.wu
    loongarch_lsx_vsubwev_d_w,                 // llvm.loongarch.lsx.vsubwev.d.w
    loongarch_lsx_vsubwev_d_wu,                // llvm.loongarch.lsx.vsubwev.d.wu
    loongarch_lsx_vsubwev_h_b,                 // llvm.loongarch.lsx.vsubwev.h.b
    loongarch_lsx_vsubwev_h_bu,                // llvm.loongarch.lsx.vsubwev.h.bu
    loongarch_lsx_vsubwev_q_d,                 // llvm.loongarch.lsx.vsubwev.q.d
    loongarch_lsx_vsubwev_q_du,                // llvm.loongarch.lsx.vsubwev.q.du
    loongarch_lsx_vsubwev_w_h,                 // llvm.loongarch.lsx.vsubwev.w.h
    loongarch_lsx_vsubwev_w_hu,                // llvm.loongarch.lsx.vsubwev.w.hu
    loongarch_lsx_vsubwod_d_w,                 // llvm.loongarch.lsx.vsubwod.d.w
    loongarch_lsx_vsubwod_d_wu,                // llvm.loongarch.lsx.vsubwod.d.wu
    loongarch_lsx_vsubwod_h_b,                 // llvm.loongarch.lsx.vsubwod.h.b
    loongarch_lsx_vsubwod_h_bu,                // llvm.loongarch.lsx.vsubwod.h.bu
    loongarch_lsx_vsubwod_q_d,                 // llvm.loongarch.lsx.vsubwod.q.d
    loongarch_lsx_vsubwod_q_du,                // llvm.loongarch.lsx.vsubwod.q.du
    loongarch_lsx_vsubwod_w_h,                 // llvm.loongarch.lsx.vsubwod.w.h
    loongarch_lsx_vsubwod_w_hu,                // llvm.loongarch.lsx.vsubwod.w.hu
    loongarch_lsx_vxor_v,                      // llvm.loongarch.lsx.vxor.v
    loongarch_lsx_vxori_b,                     // llvm.loongarch.lsx.vxori.b
    loongarch_masked_atomicrmw_add_i32,        // llvm.loongarch.masked.atomicrmw.add.i32
    loongarch_masked_atomicrmw_add_i64,        // llvm.loongarch.masked.atomicrmw.add.i64
    loongarch_masked_atomicrmw_max_i64,        // llvm.loongarch.masked.atomicrmw.max.i64
    loongarch_masked_atomicrmw_min_i64,        // llvm.loongarch.masked.atomicrmw.min.i64
    loongarch_masked_atomicrmw_nand_i32,       // llvm.loongarch.masked.atomicrmw.nand.i32
    loongarch_masked_atomicrmw_nand_i64,       // llvm.loongarch.masked.atomicrmw.nand.i64
    loongarch_masked_atomicrmw_sub_i32,        // llvm.loongarch.masked.atomicrmw.sub.i32
    loongarch_masked_atomicrmw_sub_i64,        // llvm.loongarch.masked.atomicrmw.sub.i64
    loongarch_masked_atomicrmw_umax_i32,       // llvm.loongarch.masked.atomicrmw.umax.i32
    loongarch_masked_atomicrmw_umax_i64,       // llvm.loongarch.masked.atomicrmw.umax.i64
    loongarch_masked_atomicrmw_umin_i32,       // llvm.loongarch.masked.atomicrmw.umin.i32
    loongarch_masked_atomicrmw_umin_i64,       // llvm.loongarch.masked.atomicrmw.umin.i64
    loongarch_masked_atomicrmw_xchg_i32,       // llvm.loongarch.masked.atomicrmw.xchg.i32
    loongarch_masked_atomicrmw_xchg_i64,       // llvm.loongarch.masked.atomicrmw.xchg.i64
    loongarch_masked_cmpxchg_i64,              // llvm.loongarch.masked.cmpxchg.i64
    loongarch_movfcsr2gr,                      // llvm.loongarch.movfcsr2gr
    loongarch_movgr2fcsr,                      // llvm.loongarch.movgr2fcsr
    loongarch_syscall,                         // llvm.loongarch.syscall
}; // enum
} // namespace llvm::Intrinsic
#endif

